Package: FracFixR
Type: Package
Title: Compositional Statistical Framework for RNA Fractionation
        Analysis
Version: 1.1.0
Date: 2026-05-11
Authors@R: c(
    person("Alice", "Cleynen", email = "alice.cleynen@cnrs.fr", 
           role = c("aut", "cre"), comment = c(ORCID = "0000-0001-8083-0204")),
    person("Agin", "Ravindran", role = "aut"),
    person("Nikolay", "Shirokikh", email = "nikolay.shirokikh@uwa.edu.au", 
           role = "aut", comment = c(ORCID = "0000-0001-8249-358X")))
Description: A compositional statistical framework for absolute proportion 
    estimation between fractions in RNA sequencing data. 'FracFixR' addresses 
    the fundamental challenge in fractionated RNA-seq experiments where library 
    preparation and sequencing depth obscure the original proportions of RNA 
    fractions. It reconstructs original fraction proportions using non-negative 
    linear regression, estimates the "lost" unrecoverable fraction, corrects 
    individual transcript frequencies, and performs differential proportion 
    testing between conditions. Supports any RNA fractionation protocol including
    polysome profiling, sub-cellular localization, and RNA-protein complex isolation.
License: CC BY 4.0
Encoding: UTF-8
LazyData: true
Depends: R (>= 4.0.0)
Imports: future.apply (>= 1.8.1), nnls (>= 1.4), ggplot2 (>= 3.3.5),
        dplyr (>= 1.0.7), RColorBrewer (>= 1.1-2), tidyr (>= 1.1.3),
        matrixStats (>= 0.60.0), aod (>= 1.3.1), parallelly (>=
        1.30.0), stats, utils, future, grDevices
Suggests: testthat (>= 3.0.0), knitr, rmarkdown
RoxygenNote: 7.3.2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-05-11 01:26:24 UTC; acleynen
Author: Alice Cleynen [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-8083-0204>),
  Agin Ravindran [aut],
  Nikolay Shirokikh [aut] (ORCID:
    <https://orcid.org/0000-0001-8249-358X>)
Maintainer: Alice Cleynen <alice.cleynen@cnrs.fr>
Repository: CRAN
Date/Publication: 2026-05-11 03:40:02 UTC
Built: R 4.5.2; ; 2026-05-11 06:42:26 UTC; unix

Package: FracFixR
Type: Package
Title: Compositional Statistical Framework for RNA Fractionation
        Analysis
Version: 1.1.0
Date: 2026-05-11
Authors@R: c(
    person("Alice", "Cleynen", email = "alice.cleynen@cnrs.fr", 
           role = c("aut", "cre"), comment = c(ORCID = "0000-0001-8083-0204")),
    person("Agin", "Ravindran", role = "aut"),
    person("Nikolay", "Shirokikh", email = "nikolay.shirokikh@uwa.edu.au", 
           role = "aut", comment = c(ORCID = "0000-0001-8249-358X")))
Description: A compositional statistical framework for absolute proportion 
    estimation between fractions in RNA sequencing data. 'FracFixR' addresses 
    the fundamental challenge in fractionated RNA-seq experiments where library 
    preparation and sequencing depth obscure the original proportions of RNA 
    fractions. It reconstructs original fraction proportions using non-negative 
    linear regression, estimates the "lost" unrecoverable fraction, corrects 
    individual transcript frequencies, and performs differential proportion 
    testing between conditions. Supports any RNA fractionation protocol including
    polysome profiling, sub-cellular localization, and RNA-protein complex isolation.
License: CC BY 4.0
Encoding: UTF-8
LazyData: true
Depends: R (>= 4.0.0)
Imports: future.apply (>= 1.8.1), nnls (>= 1.4), ggplot2 (>= 3.3.5),
        dplyr (>= 1.0.7), RColorBrewer (>= 1.1-2), tidyr (>= 1.1.3),
        matrixStats (>= 0.60.0), aod (>= 1.3.1), parallelly (>=
        1.30.0), stats, utils, future, grDevices
Suggests: testthat (>= 3.0.0), knitr, rmarkdown
RoxygenNote: 7.3.2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-05-11 01:26:24 UTC; acleynen
Author: Alice Cleynen [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-8083-0204>),
  Agin Ravindran [aut],
  Nikolay Shirokikh [aut] (ORCID:
    <https://orcid.org/0000-0001-8249-358X>)
Maintainer: Alice Cleynen <alice.cleynen@cnrs.fr>
Repository: CRAN
Date/Publication: 2026-05-11 03:40:02 UTC
Built: R 4.5.2; ; 2026-05-11 05:09:30 UTC; unix

# Generated by roxygen2: do not edit by hand

export(DiffPropTest)
export(FracFixR)
export(PlotComparison)
export(PlotFractions)
export(get_corrected_counts)
import(dplyr)
import(ggplot2)
importFrom(RColorBrewer,brewer.pal)
importFrom(aod,betabin)
importFrom(future,plan)
importFrom(future.apply,future_lapply)
importFrom(grDevices,dev.off)
importFrom(matrixStats,rowProds)
importFrom(nnls,nnls)
importFrom(parallelly,availableCores)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,fitted)
importFrom(stats,glm)
importFrom(stats,p.adjust)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(tidyr,pivot_longer)
importFrom(utils,read.csv)
importFrom(utils,write.csv)

## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 7,
  fig.height = 5
)

## ----installation, eval=FALSE-------------------------------------------------
# # From CRAN
# install.packages("FracFixR")
# 
# # From GitHub (development version)
# devtools::install_github("Arnaroo/FracFixR")

## ----load_package-------------------------------------------------------------
library(FracFixR)

# Set seed for reproducibility
set.seed(123)

## ----create_data--------------------------------------------------------------
# Simulate count data for 500 genes across 12 samples
n_genes <- 100
n_samples <- 12

# Generate count matrix with varying expression levels
total_counts <- matrix(
  rnbinom(n_genes * 4, mu = 100, size = 10),
  nrow = n_genes,
  dimnames = list(
    paste0("Gene", 1:n_genes),
    paste0("Sample", 1:4)
  )
)
prob=c(1/4,1/4,1/2)

# distribute counts evenly accross different fractions in Control
multinom_samples <- apply(total_counts, c(1, 2), function(x) rmultinom(1, size = x, prob = prob))
reshaped <- aperm(multinom_samples, c(3, 2, 1))  # now (n, 4, 3)
reshaped_matrix1 <- matrix(reshaped, nrow = n_genes, ncol = 12)
colnames(reshaped_matrix1) <- paste0("V", rep(1:4, each = 3), "_p", 1:3)

counts<-cbind(total_counts[,1:2],reshaped_matrix1[,c(2:3,5:6)],total_counts[,3:4],reshaped_matrix1[,c(8:9,11:12)])

# Create annotation data frame
annotation <- data.frame(
  Sample = colnames(counts),
  Condition = rep(c("Control", "Treatment"), each = 6),
  Type = rep(c("Total", "Total", "Light_Polysome", "Heavy_Polysome","Light_Polysome", "Heavy_Polysome"), 2),
  Replicate = c("Rep1","Rep2", rep("Rep1", 2), rep("Rep2", 2), "Rep1","Rep2", rep("Rep1", 2), rep("Rep2", 2))
)

print(head(annotation))

## ----run_fracfixr-------------------------------------------------------------
# Run the main analysis
results <- FracFixR(MatrixCounts = counts, Annotation = annotation)

# View the structure of results
names(results)

## ----explore_output-----------------------------------------------------------
# 1. Fraction proportions for each replicate
print(results$Fractions)

# 2. Regression coefficients
print(results$Coefficients)

# 3. Estimated Proportions (first 5 genes, first 6 samples)
print(results$Propestimates[1:5, 1:6])

## ----plot_fractions, fig.cap="Fraction proportions across replicates"---------
# Create fraction plot
frac_plot <- PlotFractions(results)
print(frac_plot)

## ----diff_test----------------------------------------------------------------
# Test for differential proportion in heavy polysomes
diff_heavy <- DiffPropTest(
  NormObject = results,
  Conditions = c("Control", "Treatment"),
  Types = "Heavy_Polysome",
  Test = "Logit"
)

# View top differentially associated genes
top_genes <- diff_heavy[order(diff_heavy$padj), ]
print(head(top_genes, 10))

## ----volcano_plot, fig.cap="Volcano plot of differential polysome association"----
volcano <- PlotComparison(
  diff_heavy,
  Conditions = c("Control", "Treatment"),
  Types = "Heavy_Polysome",
  cutoff = 20
)
print(volcano)

## ----session_info-------------------------------------------------------------
sessionInfo()

################################################################################
# FracFixR Complete Workflow Example
################################################################################
# This script demonstrates a complete analysis workflow using FracFixR
# for polysome profiling data analysis
#
# Author: FracFixR Team
# Date: 2024
################################################################################

# Load required libraries
library(FracFixR)
library(ggplot2)
library(dplyr)

# Set working directory (adjust as needed)
# setwd("~/polysome_analysis")

# ==============================================================================
# STEP 1: Load and Prepare Data
# ==============================================================================

# Option A: Use example data included with package
data(example_counts)
data(example_annotation)

# Option B: Load your own data
# counts <- read.csv("counts_matrix.csv", row.names = 1)
# annotation <- read.csv("sample_annotation.csv")
# 
# # Convert to matrix if needed
# counts_matrix <- as.matrix(counts)

# Examine the data structure
cat("Data dimensions:\n")
cat(sprintf("  Genes: %d\n", nrow(example_counts)))
cat(sprintf("  Samples: %d\n", ncol(example_counts)))
cat("\nAnnotation summary:\n")
print(table(example_annotation$Condition, example_annotation$Type))

# ==============================================================================
# STEP 2: Quality Control
# ==============================================================================

# Check library sizes
lib_sizes <- colSums(example_counts)
cat("\nLibrary sizes:\n")
print(summary(lib_sizes))

# Visualize library sizes
pdf("library_sizes.pdf", width = 10, height = 6)
par(mar = c(8, 4, 2, 2))
barplot(lib_sizes, 
        las = 2, 
        main = "Library Sizes by Sample",
        ylab = "Total Counts",
        col = rainbow(length(lib_sizes)))
dev.off()

# Check for genes with zero counts in Total samples
total_samples <- example_annotation$Type == "Total"
zero_genes <- sum(rowSums(example_counts[, total_samples]) == 0)
cat(sprintf("\nGenes with zero counts in Total samples: %d\n", zero_genes))

# Filter low-count genes (optional)
min_count <- 10
keep <- rowSums(example_counts) >= min_count
filtered_counts <- example_counts[keep, ]
cat(sprintf("Genes after filtering: %d\n", nrow(filtered_counts)))

# ==============================================================================
# STEP 3: Run FracFixR
# ==============================================================================

cat("\nRunning FracFixR analysis...\n")
fracfixr_results <- FracFixR(
  MatrixCounts = example_counts,
  Annotation = example_annotation
)

# Examine the results structure
cat("\nFracFixR output components:\n")
print(names(fracfixr_results))

# ==============================================================================
# STEP 4: Visualize Fraction Proportions
# ==============================================================================

# Plot fraction proportions
frac_plot <- PlotFractions(fracfixr_results)

# Customize the plot
frac_plot_custom <- frac_plot +
  theme_minimal() +
  theme(
    axis.text.x = element_text(angle = 45, hjust = 1, size = 12),
    legend.position = "bottom",
    plot.title = element_text(size = 16, face = "bold")
  ) +
  scale_fill_brewer(palette = "Set3")

# Save the plot
ggsave("fraction_proportions.pdf", frac_plot_custom, width = 10, height = 8)

# Extract fraction data for further analysis
fraction_data <- fracfixr_results$Fractions
cat("\nEstimated fraction proportions:\n")
print(fraction_data)

# Calculate mean proportions by condition
mean_fractions <- fraction_data %>%
  tidyr::separate(Replicate, into = c("Condition", "Rep"), sep = "_") %>%
  group_by(Condition) %>%
  summarise(across(where(is.numeric), mean, na.rm = TRUE))

cat("\nMean fraction proportions by condition:\n")
print(mean_fractions)

# ==============================================================================
# STEP 5: Differential Proportion Testing
# ==============================================================================

# Test for differential heavy polysome association
cat("\nTesting for differential heavy polysome association...\n")
diff_heavy <- DiffPropTest(
  NormObject = fracfixr_results,
  Conditions = c("Control", "Treatment"),
  Types = "Heavy_Polysome",
  Test = "GLM"
)

# Summary of results
n_tested <- nrow(diff_heavy)
n_sig_01 <- sum(diff_heavy$padj < 0.01, na.rm = TRUE)
n_sig_05 <- sum(diff_heavy$padj < 0.05, na.rm = TRUE)

cat(sprintf("\nDifferential testing summary:\n"))
cat(sprintf("  Transcripts tested: %d\n", n_tested))
cat(sprintf("  Significant at FDR < 0.01: %d\n", n_sig_01))
cat(sprintf("  Significant at FDR < 0.05: %d\n", n_sig_05))

# Get top differentially associated transcripts
top_genes <- diff_heavy %>%
  filter(!is.na(padj)) %>%
  arrange(padj) %>%
  head(20)

cat("\nTop 20 differentially associated transcripts:\n")
print(top_genes[, c("transcript", "mean_diff", "log2FC", "padj")])

# Save full results
write.csv(diff_heavy, "differential_heavy_polysome.csv", row.names = FALSE)

# ==============================================================================
# STEP 6: Create Volcano Plot
# ==============================================================================

# Basic volcano plot
volcano <- PlotComparison(
  diff_heavy,
  Conditions = c("Control", "Treatment"),
  Types = "Heavy_Polysome"
)

# Save volcano plot
ggsave("volcano_heavy_polysome.pdf", volcano, width = 12, height = 10)

# ==============================================================================
# STEP 7: Test Combined Fractions
# ==============================================================================

# Test overall ribosome association (light + heavy)
cat("\nTesting for differential overall ribosome association...\n")
diff_combined <- DiffPropTest(
  NormObject = fracfixr_results,
  Conditions = c("Control", "Treatment"),
  Types = c("Light_Polysome", "Heavy_Polysome"),
  Test = "GLM"
)

# Summary
n_sig_combined <- sum(diff_combined$padj < 0.01, na.rm = TRUE)
cat(sprintf("Transcripts with altered ribosome association: %d\n", n_sig_combined))

# Compare single vs combined fraction results
merged_results <- merge(
  diff_heavy[, c("transcript", "mean_diff", "padj")],
  diff_combined[, c("transcript", "mean_diff", "padj")],
  by = "transcript",
  suffixes = c("_heavy", "_combined")
)

# Identify transcripts significant in both analyses
both_sig <- merged_results %>%
  filter(padj_heavy < 0.01 & padj_combined < 0.01)

cat(sprintf("\nTranscripts significant in both analyses: %d\n", nrow(both_sig)))

# ==============================================================================
# STEP 8: Export Corrected Counts
# ==============================================================================

# Get corrected counts
corrected_counts <- fracfixr_results$NewData

# Save corrected counts
write.csv(corrected_counts, "corrected_counts.csv")

# Compare original vs corrected for a specific gene
gene_example <- "Gene1"
original <- example_counts[gene_example, ]
corrected <- corrected_counts[gene_example, ]

comparison <- data.frame(
  Sample = names(original),
  Original = as.numeric(original),
  Corrected = as.numeric(corrected),
  Type = example_annotation$Type
)

cat(sprintf("\nExample comparison for %s:\n", gene_example))
print(comparison)

# ==============================================================================
# STEP 9: Generate Summary Report
# ==============================================================================

# Create a summary report
report <- list(
  date = Sys.Date(),
  n_genes = nrow(example_counts),
  n_samples = ncol(example_counts),
  conditions = unique(example_annotation$Condition),
  fraction_types = unique(example_annotation$Type),
  mean_lost_fraction = mean(fraction_data$Lost),
  n_diff_heavy = n_sig_01,
  n_diff_combined = n_sig_combined
)

# Save summary
saveRDS(report, "analysis_summary.rds")

cat("\n===============================================\n")
cat("Analysis complete! Generated files:\n")
cat("  - library_sizes.pdf\n")
cat("  - fraction_proportions.pdf\n")
cat("  - differential_heavy_polysome.csv\n")
cat("  - volcano_heavy_polysome.pdf\n")
cat("  - corrected_counts.csv\n")
cat("  - analysis_summary.rds\n")
cat("===============================================\n")

# ==============================================================================
# STEP 10: Session Information
# ==============================================================================

cat("\nSession information:\n")
sessionInfo()

#' Example RNA-seq count matrix
#'
#' A matrix containing simulated RNA-seq counts for 100 genes across 12 samples.
#' The data simulates a polysome profiling experiment with two conditions
#' (Control and Treatment) and three fractions (Total, Light_Polysome, Heavy_Polysome).
#'
#' @format A numeric matrix with 100 rows (genes) and 12 columns (samples):
#' \describe{
#'   \item{rows}{Gene identifiers (Gene1 to Gene100)}
#'   \item{columns}{Sample identifiers (Sample1 to Sample12)}
#' }
#' @source Simulated data generated for package examples
#' @examples
#' data(example_counts)
#' dim(example_counts)
#' head(example_counts[, 1:6])
"example_counts"

#' Example annotation data frame
#'
#' A data frame containing sample annotations for the example_counts matrix.
#' Describes the experimental design with conditions, fraction types, and replicates.
#'
#' @format A data frame with 12 rows and 4 columns:
#' \describe{
#'   \item{Sample}{Sample identifier matching column names in example_counts}
#'   \item{Condition}{Experimental condition (Control or Treatment)}
#'   \item{Type}{Fraction type (Total, Light_Polysome, or Heavy_Polysome)}
#'   \item{Replicate}{Replicate identifier (Rep1 or Rep2)}
#' }
#' @source Simulated data generated for package examples
#' @examples
#' data(example_annotation)
#' head(example_annotation)
#' table(example_annotation$Condition, example_annotation$Type)
"example_annotation"

#' Polysome profiling annotation example
#'
#' An alternative annotation data frame for polysome profiling experiments
#' with monosome and polysome fractions.
#'
#' @format A data frame with 12 rows and 4 columns:
#' \describe{
#'   \item{Sample}{Sample identifier}
#'   \item{Condition}{Experimental condition (Control or Stress)}
#'   \item{Type}{Fraction type (Total, Monosome, or Polysome)}
#'   \item{Replicate}{Replicate identifier (Rep1 or Rep2)}
#' }
#' @source Simulated data generated for package examples
#' @examples
#' data(polysome_annotation)
#' head(polysome_annotation)
"polysome_annotation"

#' Subcellular fractionation annotation example
#'
#' An annotation data frame for subcellular fractionation experiments
#' with nuclear and cytoplasmic fractions.
#'
#' @format A data frame with 12 rows and 4 columns:
#' \describe{
#'   \item{Sample}{Sample identifier}
#'   \item{Condition}{Experimental condition (WT or Mutant)}
#'   \item{Type}{Fraction type (Total, Nuclear, or Cytoplasmic)}
#'   \item{Replicate}{Replicate identifier (Rep1 or Rep2)}
#' }
#' @source Simulated data generated for package examples
#' @examples
#' data(subcellular_annotation)
#' head(subcellular_annotation)
"subcellular_annotation"

#' @title FracFixR: Fraction Correction Framework for RNA-seq Data
#' @description A compositional statistical framework for absolute proportion estimation 
#' between fractions in RNA sequencing data. FracFixR addresses the fundamental
#' challenge in fractionated RNA-seq experiments where library preparation and
#' sequencing depth obscure the original proportions of RNA fractions.
#' @docType package
#' @name FracFixR-package
#' @aliases FracFixR-package
#' @keywords internal
"_PACKAGE"

#' @import ggplot2
#' @import dplyr
#' @importFrom future.apply future_lapply
#' @importFrom nnls nnls
#' @importFrom RColorBrewer brewer.pal
#' @importFrom tidyr pivot_longer
#' @importFrom matrixStats rowProds
#' @importFrom aod betabin
#' @importFrom parallelly availableCores
#' @importFrom stats quantile glm binomial coef p.adjust fitted residuals
#' @importFrom utils read.csv write.csv
#' @importFrom grDevices dev.off
#' @importFrom future plan
NULL

#' FracFixR: Main Function for Fraction Correction
#'
#' @description
#' This is the core function that implements the FracFixR framework. It takes
#' raw count data from total and fractionated samples and reconstructs the
#' original fraction proportions through compositional modeling.
#'
#' @param MatrixCounts A numeric matrix of raw transcript/gene counts with:
#'   \itemize{
#'     \item Rows: transcripts/genes (must have rownames)
#'     \item Columns: samples (must have colnames matching Annotation$Sample)
#'   }
#' @param Annotation A data.frame with required columns:
#'   \itemize{
#'     \item Sample: sample identifiers matching column names in MatrixCounts
#'     \item Condition: experimental condition (e.g., "Control", "Treatment")
#'     \item Type: fraction type (must include at least one "Total")
#'     \item Replicate: replicate identifier
#'   }
#' @param parallel A boolean indicating whether to use parallel processing of
#' the transcripts (default=TRUE).
#' @param st1 Lower quantile threshold for selecting informative transcripts
#'   used in the NNLS regression fit (default = 0.6). Transcripts below this
#'   quantile of Total abundance are considered too noisy for reliable regression.
#' @param st2 Upper quantile threshold for selecting informative transcripts
#'   used in the NNLS regression fit (default = 0.999). Transcripts above this
#'   quantile are potential outliers and are excluded from the regression.
#'
#' @return A list containing:
#'   \itemize{
#'     \item OriginalData: filtered input count matrix
#'     \item Annotation: input annotation data
#'     \item Propestimates: matrix of proportion estimates
#'     \item Coefficients: data.frame of regression coefficients
#'     \item Fractions: data.frame of estimated fraction proportions
#'     \item plots: list of diagnostic plots
#'   }
#'
#' @details
#' The function works by:
#' \enumerate{
#'   \item Filtering transcripts based on presence in Total samples
#'   \item For each condition and replicate, fitting NNLS regression
#'   \item Estimating global fraction weights and individual transcript proportions
#'   \item Calculating the "lost" unrecoverable fraction
#' }
#'
#' @examples
#' # Load example data
#' data(example_counts)
#' data(example_annotation)
#' 
#' # Run FracFixR
#' results <- FracFixR(example_counts, example_annotation, parallel=FALSE)
#' 
#' # View fraction proportions
#' print(results$Fractions)
#'
#' @references
#' Cleynen et al. FracFixR: A compositional statistical framework for
#' absolute proportion estimation between fractions in RNA sequencing data.
#'
#' @export
FracFixR <- function(MatrixCounts, Annotation, st1 = 0.6, st2 = 0.999, parallel = TRUE) {
  # --------------------------------------------------------------------------
  # Input validation: Ensure matrix format and required structure
  # --------------------------------------------------------------------------
  stopifnot("MatrixCounts must be a numeric matrix" = is.matrix(MatrixCounts),
            "MatrixCounts must contain numeric values" = is.numeric(MatrixCounts),
            "MatrixCounts must have row names" = !is.null(rownames(MatrixCounts)),
            "MatrixCounts must have column names" = !is.null(colnames(MatrixCounts)))
  
  stopifnot("Annotation must be a data.frame" = is.data.frame(Annotation),
            "Annotation must contain required columns" = 
              all(c("Sample","Condition","Type","Replicate") %in% colnames(Annotation)))
  
  # Verify all samples in counts matrix are documented in annotation
  if (!all(colnames(MatrixCounts) %in% Annotation$Sample))
    stop("All MatrixCounts columns must be in Annotation$Sample")
  
  # Check that at least one Total sample is present (required for normalization)
  if (!any(Annotation$Type == "Total")) {
    stop("Annotation must include at least one sample with Type == 'Total'")
  }
  
  # Check for minimum replicates per condition
  reps_per_condition <- Annotation %>%
    dplyr::group_by(.data$Condition) %>%
    dplyr::summarise(n_reps = dplyr::n_distinct(.data$Replicate), .groups = "drop")
  
  if (any(reps_per_condition$n_reps < 2)) {
    warning("Some conditions have fewer than 2 replicates. Statistical tests may have limited power.")
  }
  
  # --------------------------------------------------------------------------
  # Setup parallel processing for computational efficiency
  # --------------------------------------------------------------------------
  
  if (parallel) {
    message("Setting up parallel processing...")
    future::plan(future::multisession, workers = parallelly::availableCores())
  } else {
    future::plan(future::sequential)  # safe default
  }
  # --------------------------------------------------------------------------
  # Filter transcripts: Keep only those present in Total samples
  # This ensures we work with transcripts that are detectable in the whole cell
  # --------------------------------------------------------------------------
  message("Filtering transcripts based on Total samples...")
  wct_idx <- which(Annotation$Type == "Total")
  if (length(wct_idx) > 1) {
    # Multiple Total samples: keep transcripts present in at least one
    DataNorm <- MatrixCounts[rowSums(MatrixCounts[, wct_idx, drop = FALSE]) > 0, , drop = FALSE]
  } else {
    # Single Total sample: keep transcripts with non-zero counts
    DataNorm <- MatrixCounts[MatrixCounts[, wct_idx] > 0, , drop = FALSE]
  }
  message(sprintf("Retained %d transcripts present in Total samples", nrow(DataNorm)))
  
  # Combine transposed count data with annotation for easier manipulation
  Data <- cbind(t(DataNorm), Annotation[match(colnames(DataNorm), Annotation$Sample), ])
  
  # --------------------------------------------------------------------------
  # Initialize storage containers for results
  # --------------------------------------------------------------------------
  PropestimatesComplete <- NULL  # Proportion estimates
  NewDataComplete       <- NULL  # Corrected count matrix
  CoefficientComplete <- list()  # Regression coefficients
  FractionsComplete <- list()    # Fraction proportions
  all_plots <- list()           # Diagnostic plots
  rep_ids <- character()        # Replicate identifiers

  # --------------------------------------------------------------------------
  # Process each experimental condition separately
  # --------------------------------------------------------------------------
  n_conditions <- length(unique(Annotation$Condition))
  cond_counter <- 0
  
  for (cond in unique(Annotation$Condition)) {
    cond_counter <- cond_counter + 1
    message(sprintf("\nProcessing condition %d/%d: %s", cond_counter, n_conditions, cond))
    
    # Extract data for current condition
    Datacond <- subset(Data, Condition == cond)
    DataDD <- DataNorm[, Annotation$Condition == cond, drop = FALSE]
    AnnoCond <- subset(Annotation, Condition == cond)
    wct_cond <- which(AnnoCond$Type == "Total")

    # Calculate total RNA abundance across Total samples for this condition
    if (length(wct_cond) > 1) {
      TotalSum <- rowSums(DataDD[, wct_cond, drop = FALSE], na.rm = TRUE)
    } else {
      TotalSum <- DataDD[, wct_cond]
      TotalSum[is.na(TotalSum)] <- NA   # keep NAs explicit but let quantile skip them
    }
    if (!is.numeric(TotalSum))
      stop("TotalSum must be numeric")

    # ----------------------------------------------------------------------
    # Select informative transcripts for regression
    # Use st1-st2 quantile range to avoid:
    # - Low abundance transcripts (noisy)
    # - Very high abundance transcripts (potential outliers)
    # ----------------------------------------------------------------------
    s1 <- quantile(TotalSum, st1, na.rm = TRUE)
    s2 <- quantile(TotalSum, st2, na.rm = TRUE)
    message(sprintf("  Selecting transcripts with %.1f - %.1f%% quantiles (range: %.1f - %.1f)",
                    st1 * 100, st2 * 100, s1, s2))

    # Create list of transcripts in the selected abundance range
    # Ensure at least 7 counts to avoid very low abundance noise
    transcriptlist <- rownames(DataDD)[!is.na(TotalSum) & TotalSum > max(s1, 7) & TotalSum < s2]
    message(sprintf("  Selected %d transcripts for regression", length(transcriptlist)))

    # Check if we have enough transcripts
    if (length(transcriptlist) == 0) {
      stop(sprintf("No transcripts selected for regression in condition %s", cond))
    }
    
    if (length(transcriptlist) < 10) {
      warning(sprintf("Only %d transcripts selected for condition %s (minimum recommended: 10)", 
                     length(transcriptlist), cond))
    }

    # ----------------------------------------------------------------------
    # Process each replicate within the condition
    # ----------------------------------------------------------------------
    n_reps <- length(unique(Datacond$Replicate))
    rep_counter <- 0
    
    for (rep in unique(Datacond$Replicate)) {
      rep_counter <- rep_counter + 1
      message(sprintf("  Processing replicate %d/%d: %s", rep_counter, n_reps, rep))
      
      # Extract replicate data and ensure Total is first
      Datatemp <- subset(Datacond, Replicate == rep)
      Datatemp <- Datatemp[order(Datatemp$Type != "Total"), ]
      
      # Extract count measurements (exclude metadata columns)
      measurements <- Datatemp[, setdiff(names(Datatemp), c("Sample","Type","Replicate","Condition"))]
      if (nrow(measurements) < 2)
        stop("Each replicate must have at least two types (Total + one fraction)")
      
      # Replace first row with calculated TotalSum for consistency
      measurements[1, ] <- TotalSum
      sample_names <- Datatemp$Sample
      sample_names[1] <- "Total"  # Standardize Total sample name
      
      # Prepare data matrix for ProcessReplicate function
      DataProcess <- as.data.frame(t(measurements))
      colnames(DataProcess) <- sample_names

      # ------------------------------------------------------------------
      # Core processing: fit NNLS model for this replicate
      # ------------------------------------------------------------------
      results <- ProcessReplicate(DataProcess, transcriptlist)
      
      # Validate results structure
      stopifnot(is.list(results),
                all(c("Propestimates","Coefficients","Fractions", "plot") %in% names(results)))

      # ------------------------------------------------------------------
      # Assign meaningful names to results and compile
      # ------------------------------------------------------------------
      colnames(results$Propestimates) <- Datatemp$Sample
      colnames(results$NewData)       <- Datatemp$Sample
      names(results$Coefficients) <- Datatemp$Type
      names(results$Coefficients)[1] <- "Lost"  # First coefficient is intercept (lost fraction)
      names(results$Fractions) <- Datatemp$Type[-1]  # Exclude Total from fractions

      # Bind results to complete matrices
      # Note: For very large datasets, consider pre-allocating matrices for efficiency
      PropestimatesComplete <- if (is.null(PropestimatesComplete)) results$Propestimates else cbind(PropestimatesComplete, results$Propestimates)
      NewDataComplete       <- if (is.null(NewDataComplete))       results$NewData       else cbind(NewDataComplete,       results$NewData)

      # Store replicate-specific results with unique identifiers
      FractionsComplete[[paste(cond, rep, sep = "_")]] <- results$Fractions
      CoefficientComplete[[paste(cond,rep,sep="_")]] <- results$Coefficients
      all_plots[[paste(cond, rep, sep = "_")]] <- results$plot
      rep_ids <- c(rep_ids, paste(cond, rep, sep = "_"))
    }
  }

  message("\nFinalizing results...")
  
  # --------------------------------------------------------------------------
  # Reorder results to match original sample order
  # --------------------------------------------------------------------------
  Propestimates <- PropestimatesComplete[, Annotation$Sample, drop = FALSE]
  NewData       <- NewDataComplete[,       Annotation$Sample, drop = FALSE]
  
  # --------------------------------------------------------------------------
  # Compile fraction results into a single data frame
  # --------------------------------------------------------------------------
  Fraction <- do.call(rbind, FractionsComplete)
  Fraction <- as.data.frame(Fraction)
  # Calculate "Lost" fraction as remainder (1 - sum of observed fractions)
  Fraction$Lost <- rep(1, nrow(Fraction)) - rowSums(Fraction)
  Fraction$Replicate <- rownames(Fraction)
  rownames(Fraction) <- NULL
  
  # Compile coefficient results
  Coeff <- do.call(rbind, CoefficientComplete)
  Coeff <- as.data.frame(Coeff)
  Coeff$Replicate <- rownames(Coeff)
  rownames(Coeff) <- NULL

  message("FracFixR analysis complete!")
  
  # --------------------------------------------------------------------------
  # Return comprehensive results object
  # --------------------------------------------------------------------------
  list(
    OriginalData = DataNorm,
    Annotation = Annotation,
    Propestimates = Propestimates,
    NewData = NewData,
    Coefficients = Coeff,
    Fractions = Fraction,
    plots = all_plots
  )
}

#' ProcessReplicate: Core NNLS Regression for Individual Replicates
#'
#' @description
#' This function implements the mathematical core of FracFixR: fitting a
#' non-negative least squares (NNLS) regression to estimate fraction weights
#' and correct individual transcript abundances.
#'
#' @param RepMat Data frame with transcripts as rows, samples as columns.
#'   Must include a "Total" column representing the whole cell lysate
#' @param transcriptlist Character vector of transcript IDs to use for regression.
#'   These should be informative transcripts in the appropriate abundance range
#'
#' @return List containing:
#'   \itemize{
#'     \item Propestimates: Proportion estimates for each transcript
#'     \item Coefficients: NNLS regression coefficients (fraction weights)
#'     \item Fractions: Normalized fraction proportions
#'     \item plot: Diagnostic plot of fitted vs residuals
#'   }
#'
#' @details
#' Mathematical basis:
#' \deqn{Total = \alpha_0 + \alpha_1 \times Fraction1 + \alpha_2 \times Fraction2 + ... + \epsilon}
#' Where \eqn{\alpha_0} represents the "lost" fraction and other \eqn{\alpha_i} are fraction weights
#'
#' @keywords internal
ProcessReplicate <- function(RepMat, transcriptlist) {
  Data <- data.frame(RepMat)
  n <- ncol(Data)

  # Validate presence of Total column (required for regression)
  if (!"Total" %in% colnames(RepMat)) {
    stop("RepMat must include a column named 'Total'. At least one sample of type 'Total' is required.")
  }

  # --------------------------------------------------------------------------
  # Prepare training data: subset to informative transcripts
  # --------------------------------------------------------------------------
  DataT <- Data[transcriptlist, ]
  # Remove any transcripts with NA values to ensure clean regression
  DataT <- DataT[rowSums(is.na(DataT)) == 0, ]
  
  # Create predictor matrix (all fractions except Total)
  X <- as.matrix(DataT[!is.element(colnames(DataT), "Total")])

  # --------------------------------------------------------------------------
  # Fit NNLS regression with intercept
  # The intercept captures the "lost" fraction not represented in sequenced samples
  # --------------------------------------------------------------------------
  X_with_intercept <- cbind(1, X)  # Add column of 1s for intercept
  fit <- nnls::nnls(X_with_intercept, DataT$Total)
  coef <- coef(fit)
  
  # Create diagnostic plot data
  PlotFit <- data.frame(
    fitted = as.vector(X_with_intercept %*% coef), 
    residuals = DataT$Total - as.vector(X_with_intercept %*% coef)
  )
  plotfit <- ggplot2::ggplot(PlotFit, ggplot2::aes(x = fitted, y = residuals)) + 
    ggplot2::geom_point() + 
    ggplot2::geom_hline(yintercept = 0)

  # --------------------------------------------------------------------------
  # Apply fitted model to all transcripts (not just training set)
  # --------------------------------------------------------------------------
  X_new <- as.matrix(Data[!is.element(colnames(Data), "Total")])
  seen_predict <- X_new %*% coef[-1]  # Predictions without intercept
  X_new <- cbind(1, X_new)
  predictions <- X_new %*% coef  # Full predictions including intercept

  # --------------------------------------------------------------------------
  # Calculate library sizes and fraction proportions
  # --------------------------------------------------------------------------
  Nlib <- colSums(Data)  # Library sizes for each sample
  Fractions <- c()
  Coefficients <- c(coef[1])  # Start with intercept (lost fraction)

  # Convert regression coefficients to fraction proportions
  # Account for different library sizes between Total and fractions
  for (j in 2:n) {
    # Fraction proportion = coefficient × fraction_library_size / total_library_size
    Fractions <- c(Fractions, coef[j] * Nlib[j] / Nlib[1])
    Coefficients <- c(Coefficients, coef[j])
  }
  names(Coefficients) <- colnames(Data)

  # --------------------------------------------------------------------------
  # Calculate proportion estimates for each transcript
  # --------------------------------------------------------------------------
  Propestimates <- Data
  Propestimates[, 1] <- ceiling(predictions)  # Total column gets predicted values
  
  # For each fraction, calculate proportion relative to predicted total
  # Use max() to ensure non-zero denominator
  for (j in 2:n) {
    Propestimates[, j] <- Data[, j] * coef[j] / apply(cbind(Data[, 1], seen_predict, 1), 1, max)
  }

  # --------------------------------------------------------------------------
  # NewData: corrected count matrix (proportion × predicted Total, rounded)
  # This converts proportions back to the count scale for each fraction.
  # --------------------------------------------------------------------------
  NewData <- Propestimates
  for (j in 2:n) {
    NewData[, j] <- round(Propestimates[, j] * Propestimates[, 1])
  }

  # Return comprehensive results
  return(list(
    Propestimates = Propestimates,
    NewData = NewData,
    Coefficients = Coefficients,
    Fractions = Fractions,
    plot = plotfit
  ))
}

#' DiffPropTest: Statistical Testing for Differential Proportions
#'
#' @description
#' Performs statistical testing to identify transcripts with significantly
#' different proportions between conditions in specified fraction(s).
#' Implements three test options: GLM (most powerful), Logit, and Wald.
#'
#' @param NormObject Output from FracFixR() function
#' @param Conditions Character vector of exactly 2 conditions to compare
#' @param Types Character vector of fraction type(s) to analyze.
#'   Can be single fraction or multiple (will be combined)
#' @param Test Statistical test to use: "GLM", "Logit", or "Wald"
#'
#' @return Data frame with columns:
#'   \itemize{
#'     \item transcript: transcript identifier
#'     \item mean_success_cond1/2: mean proportions in each condition
#'     \item mean_diff: difference in proportions
#'     \item log2FC: log2 fold change
#'     \item pval: p-value from statistical test
#'     \item padj: FDR-adjusted p-value
#'   }
#'
#' @details
#' \itemize{
#'   \item GLM: Uses binomial generalized linear model (most statistically powerful)
#'   \item Logit: Faster alternative using logit transformation
#'   \item Wald: Beta-binomial Wald test for overdispersed count data
#' }
#'
#' @examples
#' data(example_counts)
#' data(example_annotation)
#' 
#' # Run FracFixR
#' results <- FracFixR(example_counts, example_annotation, parallel=FALSE)
#' # Run differential testing
#' diff_results <- DiffPropTest(results,
#'                             Conditions = c("Control", "Treatment"),
#'                             Types = "Heavy_Polysome",
#'                             Test = "GLM")
#'
#' @export
DiffPropTest <- function(NormObject, Conditions, Types, Test = c("GLM", "Logit", "Wald")) {
  Test <- match.arg(Test)

  # Validate that Total samples exist in annotation
  if (!any(NormObject$Annotation$Type == "Total")) {
    stop("NormObject$Annotation must contain at least one sample of Type 'Total'.")
  }

  # Validate requested conditions exist
  if (!all(Conditions %in% unique(NormObject$Annotation$Condition))) {
    stop("Some specified Conditions are not found in NormObject$Annotation.")
  }

  # Validate requested types exist
  if (!all(Types %in% unique(NormObject$Annotation$Type))) {
    stop("Some specified Types are not found in NormObject$Annotation.")
  }
  
  # Create descriptive type label for messages
  if (length(Types)==1) type=Types else type=paste(Types[1], Types[2],sep="+")

  # Extract relevant data for the specified conditions and types
  Extraction <- extract_condition_matrix(NormObject$OriginalData, 
                                       NormObject$Propestimates, 
                                       NormObject$Annotation, 
                                       Conditions, 
                                       Types)

  # Prepare sample information with condition as factor
  sample_info <- Extraction$annotation %>%
    dplyr::select(Sample, Condition) %>%
    dplyr::mutate(Condition = factor(Condition, levels = Conditions))

  # --------------------------------------------------------------------------
  # Execute selected statistical test
  # --------------------------------------------------------------------------
  
  if (Test == "GLM") {
    message(paste('Performing GLM test comparing Conditions', Conditions[1], 'and', 
                Conditions[2], 'in the', type, 'fraction'))
    
    # Select transcripts with non-zero counts in all samples
    transcripts <- rownames(Extraction$counts[matrixStats::rowProds(as.matrix(Extraction$counts)) > 0, ])
    
    # Progress message for parallel processing
    message(sprintf("Testing %d transcripts using parallel processing...", length(transcripts)))
    
    # Run GLM in parallel for efficiency
    results_list <- future.apply::future_lapply(transcripts, run_glm, 
                                counts = Extraction$counts, 
                                successes = Extraction$successes, 
                                sample_info = sample_info)
    results_df <- dplyr::bind_rows(results_list)
  }

  if (Test == "Logit") {
    message(paste('Performing Logit test comparing Conditions', Conditions[1], 'and', 
                Conditions[2], 'in the', Types, 'fraction'))
    results_df <- logit_diff_test(counts = Extraction$counts, 
                                successes = Extraction$successes, 
                                annotation = sample_info)
  }

  if (Test == "Wald") {
    message(paste('Performing Wald test comparing Conditions', Conditions[1], 'and', 
                Conditions[2], 'in the', Types, 'fraction'))
    # Convert proportions to counts for beta-binomial model
    success_counts <- round(Extraction$successes * Extraction$counts)
    results_df <- beta_binomial_wald(counts = Extraction$counts, 
                                   successes = success_counts, 
                                   annotation = sample_info)
  }

  # Apply multiple testing correction (Benjamini-Hochberg FDR)
  message("Applying FDR correction...")
  results_df$padj <- p.adjust(results_df$pval, method = "BH")
  
  # Summary statistics
  n_sig <- sum(results_df$padj < 0.01, na.rm = TRUE)
  message(sprintf("Analysis complete. Found %d transcripts with padj < 0.01", n_sig))
  
  return(results_df)
}

#' extract_condition_matrix: Extract and Prepare Data for Statistical Testing
#'
#' @description
#' Extracts count and proportion data for specified conditions and fraction types.
#' Handles both single fraction and combined fraction analyses.
#'
#' @param originalcounts Original count matrix
#' @param proportions Proportion estimates from FracFixR
#' @param annotation Sample annotation data frame
#' @param conditions Vector of conditions to extract
#' @param types Vector of fraction types to analyze
#'
#' @return List containing:
#'   \itemize{
#'     \item counts: Total counts from whole cell samples
#'     \item successes: Proportion data for specified fractions
#'     \item annotation: Filtered and processed annotation
#'   }
#'
#' @keywords internal
extract_condition_matrix <- function(originalcounts, proportions, annotation, conditions, types) {
  # --------------------------------------------------------------------------
  # Extract Total samples for the specified conditions
  # These serve as the denominator in proportion calculations
  # --------------------------------------------------------------------------
  ann_wct <- annotation %>%
    dplyr::filter(Condition %in% conditions, .data$Type == "Total")

  if (nrow(ann_wct) == 0) {
    stop("No samples with Type 'Total' found for the specified conditions.")
  }

  # Create count matrix from Total samples
  wct_samples <- ann_wct$Sample
  count_matrix <- originalcounts[, wct_samples, drop = FALSE]
  # Rename columns to include condition and replicate info
  colnames(count_matrix) <- paste(ann_wct$Condition, ann_wct$Replicate, sep = "_")

  # Filter annotation to specified conditions and types
  ann_filtered <- annotation %>%
    dplyr::filter(Condition %in% conditions, Type %in% types)

  # --------------------------------------------------------------------------
  # Handle single fraction vs combined fraction analysis
  # --------------------------------------------------------------------------
  
  if (length(types) == 1) {
    # Single fraction analysis: straightforward extraction
    selected_samples <- ann_filtered$Sample
    result_matrix <- proportions[, selected_samples, drop = FALSE]
    result_annotation <- ann_filtered %>%
      dplyr::filter(.data$Sample %in% selected_samples)
    
    # Standardize column names
    colnames(result_matrix) <- paste(ann_filtered$Condition, ann_filtered$Replicate, sep = "_")
    result_annotation$Sample <- paste(ann_filtered$Condition, ann_filtered$Replicate, sep = "_")
    
  } else {
    # Multiple fraction analysis: sum proportions across fraction types
    result_list <- list()
    ann_list <- list()

    # Process each condition-replicate combination
    for (cond in unique(ann_filtered$Condition)) {
      for (rep in sort(unique(ann_filtered$Replicate))) {
        temp <- ann_filtered %>%
          dplyr::filter(Condition == cond, Replicate == rep)

        # Sum proportions across all requested fraction types
        summed_vector <- NULL
        for (t in types) {
          samples <- temp$Sample[temp$Type == t]
          if (length(samples) > 0) {
            vec <- rowSums(proportions[, samples, drop = FALSE])
            summed_vector <- if (is.null(summed_vector)) vec else summed_vector + vec
          }
        }

        # Store results with standardized naming
        colname <- paste(cond, rep, sep = "_")
        result_list[[colname]] <- summed_vector

        # Create corresponding annotation entry
        ann_list[[colname]] <- data.frame(
          Sample = colname,
          Condition = cond,
          Type = paste(types, collapse = "+"),
          Replicate = rep,
          stringsAsFactors = FALSE
        )
      }
    }

    # Combine results
    result_matrix <- do.call(cbind, result_list)
    result_annotation <- do.call(rbind, ann_list)
  }

  return(list(
    counts = count_matrix,
    successes = result_matrix,
    annotation = result_annotation
  ))
}

#' run_glm: Binomial GLM for Single Transcript
#'
#' @description
#' Fits a binomial generalized linear model to test for differential
#' proportions between conditions for a single transcript.
#'
#' @param transcript Transcript identifier
#' @param counts Total count matrix
#' @param successes Proportion matrix
#' @param sample_info Sample metadata with Condition factor
#'
#' @return Data frame with test results for this transcript
#'
#' @keywords internal
run_glm <- function(transcript, counts, successes, sample_info) {
  # Validate transcript exists in data
  if (!(transcript %in% rownames(counts))) {
    stop(paste("Transcript", transcript, "not found in count matrix."))
  }

  # Ensure matrix alignment
  if (!all(colnames(counts) == colnames(successes))) {
    stop("Column names of 'counts' and 'successes' must match.")
  }

  # Verify all samples are in metadata
  if (!all(colnames(counts) %in% sample_info$Sample)) {
    stop("All sample names in counts/successes must be present in sample_info$Sample.")
  }

  # Extract data for this transcript
  valid_samples <- colnames(counts)
  total <- counts[transcript, valid_samples]
  prop_success <- successes[transcript, valid_samples]
  # Convert proportions to counts for binomial model
  success <- round(total * prop_success)
  failure <- total - success

  # Build data frame for GLM
  df_tmp <- data.frame(
    Sample = valid_samples,
    successes = as.numeric(success),
    failures = as.numeric(failure),
    prop = as.numeric(prop_success)
  ) %>%
    dplyr::left_join(sample_info, by = "Sample")

  # Handle edge case: all zeros
  if (any(df_tmp$successes + df_tmp$failures == 0)) {
    return(data.frame(
      transcript = transcript,
      mean_success_cond1 = NA,
      mean_success_cond2 = NA,
      mean_diff = NA,
      log2FC = NA,
      pval = NA
    ))
  }

  # Fit GLM with error handling
  result <- tryCatch({
    # Binomial GLM: success/failure ~ Condition
    fit <- stats::glm(cbind(successes, failures) ~ Condition, data = df_tmp, family = binomial)
    coeffs <- summary(fit)$coefficients
    # Extract p-value for condition effect
    pval <- coeffs[grep("^Condition", rownames(coeffs)), "Pr(>|z|)"][1]

    # Calculate group means
    group_means <- df_tmp %>%
      dplyr::group_by(Condition) %>%
      dplyr::summarise(mean_prop = mean(prop, na.rm = TRUE), .groups = "drop")

    # Ensure we have exactly 2 conditions
    if (nrow(group_means) != 2) {
      return(data.frame(
        transcript = transcript,
        mean_success_cond1 = NA,
        mean_success_cond2 = NA,
        mean_diff = NA,
        log2FC = NA,
        pval = NA
      ))
    }

    # Calculate effect sizes
    group_means <- group_means[order(group_means$Condition), ]
    mean_diff <- diff(group_means$mean_prop)
    log2FC <- log2(group_means$mean_prop[2] / group_means$mean_prop[1])

    data.frame(
      transcript = transcript,
      mean_success_cond1 = group_means$mean_prop[1],
      mean_success_cond2 = group_means$mean_prop[2],
      mean_diff = mean_diff,
      log2FC = log2FC,
      pval = pval
    )
  }, error = function(e) {
    # Return NA results if model fitting fails
    data.frame(
      transcript = transcript,
      mean_success_cond1 = NA,
      mean_success_cond2 = NA,
      mean_diff = NA,
      log2FC = NA,
      pval = NA
    )
  })

  return(result)
}

#' logit_diff_test: Logit-based Differential Test
#'
#' @description
#' Alternative to GLM using logit transformation. Faster but potentially
#' less powerful than the full GLM approach.
#'
#' @param counts Total count matrix
#' @param successes Proportion matrix  
#' @param annotation Sample metadata
#'
#' @return Data frame with test results for all transcripts
#'
#' @keywords internal
logit_diff_test <- function(counts, successes, annotation) {
  # Validate matrix alignment
  if (!all(rownames(successes) == rownames(counts))) {
    stop("Row names of 'successes' and 'counts' must match.")
  }

  if (!all(colnames(successes) %in% annotation$Sample)) {
    stop("Not all column names in 'successes' are found in 'annotation$Sample'.")
  }

  # Process each transcript
  results <- lapply(rownames(counts), function(transcript) {
    # Build data frame for this transcript
    df <- data.frame(
      counts = as.numeric(counts[transcript, ]),
      prop = as.numeric(successes[transcript, ]),
      successes = round(as.numeric(counts[transcript, ]) * as.numeric(successes[transcript, ])),
      Sample = colnames(counts)
    ) %>%
    dplyr::left_join(annotation, by = "Sample")

    # Check for valid comparison
    if (length(unique(df$Condition)) < 2) {
      return(data.frame(
        transcript = transcript,
        mean_success_cond1 = NA,
        mean_success_cond2 = NA,
        mean_diff = NA,
        log2FC = NA,
        pval = NA
      ))
    }

    # Fit model with error handling
    tryCatch({
    group_means <- df %>%
      dplyr::group_by(Condition) %>%
      dplyr::summarise(mean_prop = mean(prop, na.rm = TRUE), .groups = "drop")
      
      # Calculate condition means
      mean_success_cond1 = group_means$mean_prop[1]
      mean_success_cond2 = group_means$mean_prop[2]
      mean_diff <- as.numeric(mean_success_cond2 - mean_success_cond1)

      # Fit binomial GLM
      model <- stats::glm(cbind(successes, counts - successes) ~ Condition, 
                   family = binomial, data = df)
      summary_model <- summary(model)
      
      # Extract log2 fold change and p-value
      log2FC <- log2(exp(summary_model$coefficients[2, 1]))
      pval <- summary_model$coefficients[2, 4]

      data.frame(
        transcript = transcript,
        mean_success_cond1 = mean_success_cond1,
        mean_success_cond2 = mean_success_cond2,
        mean_diff = mean_diff,
        log2FC = log2FC,
        pval = pval
      )
    }, error = function(e) {
      data.frame(
        transcript = transcript,
        mean_success_cond1 = NA,
        mean_success_cond2 = NA,
        mean_diff = NA,
        log2FC = NA,
        pval = NA
      )
    })
  })

  do.call(rbind, results)
}

#' beta_binomial_wald: Beta-Binomial Wald Test
#'
#' @description
#' Implements Wald test using beta-binomial distribution to account for
#' overdispersion in count data. Useful when variance exceeds that expected
#' under binomial distribution.
#'
#' @param counts Total count matrix
#' @param successes Success count matrix (not proportions)
#' @param annotation Sample metadata
#'
#' @return Data frame with test results for all transcripts
#'
#' @keywords internal
beta_binomial_wald <- function(counts, successes, annotation) {
  # Validate matrix alignment
  if (!all(rownames(successes) == rownames(counts))) {
    stop("Row names of 'successes' and 'counts' must match.")
  }

  if (!all(colnames(successes) %in% annotation$Sample)) {
    stop("Not all samples in 'successes' matrix are found in 'annotation$Sample'.")
  }

  # Process each transcript
  results <- lapply(rownames(counts), function(transcript) {
    # Build data frame for this transcript
    df <- data.frame(
      counts = as.numeric(counts[transcript, ]),
      successes = round(as.numeric(counts[transcript, ]) * as.numeric(successes[transcript, ])),
      sample = colnames(counts)
    ) %>%
      dplyr::left_join(annotation, by = c("sample" = "Sample"))

    # Ensure Condition is a factor
    df$Condition <- factor(df$Condition)
    cond_levels <- levels(df$Condition)

    # Check for valid comparison (need exactly 2 conditions)
    if (length(cond_levels) != 2) {
      return(data.frame(
        transcript = transcript,
        mean_success_cond1 = NA,
        mean_success_cond2 = NA,
        mean_diff = NA,
        log2FC = NA,
        pval = NA
      ))
    }

    # Fit beta-binomial model with error handling
    tryCatch({
      # Calculate condition means
      mean_success_cond1 <- mean(df$successes[df$Condition == cond_levels[1]])
      mean_success_cond2 <- mean(df$successes[df$Condition == cond_levels[2]])
      mean_diff <- mean_success_cond2 - mean_success_cond1

      # Fit beta-binomial model
      model <- aod::betabin(cbind(successes, counts - successes) ~ Condition, ~1, data = df)
      
      # Extract p-value and effect size
      coef_name <- paste0("Condition", cond_levels[2])
      pval <- summary(model)$coef[coef_name, "Pr(>Chi)"]
      log2FC <- log2(exp(coef(model)[coef_name]))

      data.frame(
        transcript = transcript,
        mean_success_cond1 = mean_success_cond1,
        mean_success_cond2 = mean_success_cond2,
        mean_diff = mean_diff,
        log2FC = log2FC,
        pval = pval
      )
    }, error = function(e) {
      data.frame(
        transcript = transcript,
        mean_success_cond1 = NA,
        mean_success_cond2 = NA,
        mean_diff = NA,
        log2FC = NA,
        pval = NA
      )
    })
  })

  do.call(rbind, results)
}

#' PlotFractions: Visualize Fraction Proportions
#'
#' @description
#' Creates a stacked bar plot showing the distribution of RNA across fractions
#' for each replicate, including the "lost" fraction.
#'
#' @param FracFixed Output from FracFixR() function
#'
#' @return ggplot2 object showing fraction proportions
#'
#' @examples
#' data(example_counts)
#' data(example_annotation)
#' 
#' # Run FracFixR
#' results <- FracFixR(example_counts, example_annotation, parallel=FALSE)
#' # Create fraction plot
#' frac_plot <- PlotFractions(results)
#' # Save plot with ggsave("fractions.pdf", frac_plot, width = 10, height = 8)
#'
#' @export
PlotFractions <- function(FracFixed) {
  df_temp <- FracFixed$Fractions
  
  # --------------------------------------------------------------------------
  # Reshape data from wide to long format for ggplot
  # --------------------------------------------------------------------------
  df_long <- df_temp %>%
    tidyr::pivot_longer(
      cols = -Replicate,  # All columns except Replicate are proportions
      names_to = "Condition",
      values_to = "Proportion"
    )

  # --------------------------------------------------------------------------
  # Set up color scheme with "Lost" fraction always in grey
  # --------------------------------------------------------------------------
  conditions <- unique(df_long$Condition)
  other_conditions <- setdiff(conditions, "Lost")

  # Use colorblind-friendly palette for non-Lost conditions
  n_colors <- length(other_conditions)
  palette_colors <- RColorBrewer::brewer.pal(max(3, min(8, n_colors)), "Set2")[1:n_colors]
  names(palette_colors) <- other_conditions

  # Add grey for "Lost" fraction
  colors_named <- c(palette_colors, Lost = "grey80")

  # Set factor levels to ensure "Lost" appears at bottom of stack
  df_long <- df_long %>%
    dplyr::mutate(Condition = factor(Condition, levels = c("Lost", other_conditions)))

  # --------------------------------------------------------------------------
  # Create stacked bar plot
  # --------------------------------------------------------------------------
  G <- ggplot2::ggplot(df_long, ggplot2::aes(x = Replicate, y = Proportion, fill = Condition)) +
    ggplot2::geom_bar(stat = "identity") +
    ggplot2::theme_minimal() +
    ggplot2::labs(
      title = "Evaluation of Fraction Proportions",
      y = "Proportion",
      x = "Replicate"
    ) +
    ggplot2::scale_fill_manual(values = colors_named) +
    ggplot2::theme(
      axis.text.x = ggplot2::element_text(angle = 45, hjust = 1),
      text = ggplot2::element_text(size = 14)
    )

  return(G)
}

#' PlotComparison: Create Volcano Plot for Differential Results
#'
#' @description
#' Generates avolcano plot showing transcripts with significant
#' differential proportions between conditions.
#'
#' @param DiffPropResult Output from DiffPropTest() function
#' @param Conditions Character vector of conditions being compared
#' @param Types Character vector of fraction types analyzed
#' @param cutoff Optional y-axis maximum for plot
#'
#' @return Volcano plot-type object
#'
#' @examples
#' data(example_counts)
#' data(example_annotation)
#' 
#' # Run FracFixR
#' results <- FracFixR(example_counts, example_annotation,parallel=FALSE)
#' # Run differential testing
#' diff_results <- DiffPropTest(results,
#'                             Conditions = c("Control", "Treatment"),
#'                             Types = "Heavy_Polysome",
#'                             Test = "GLM")
#' # Create volcano plot
#' volcano <- PlotComparison(diff_results, 
#'                          Conditions = c("Control", "Treatment"),
#'                          Types = "Heavy_Polysome")
#'
#' @export
PlotComparison <- function(DiffPropResult, Conditions=NULL, Types=NULL, cutoff=NULL) {
  # --------------------------------------------------------------------------
  # Generate informative title and subtitle
  # --------------------------------------------------------------------------
  if (length(Types)==1) {
    subtitle <- paste(Types, 'comparison')
  } else if (length(Types)==2) {
    subtitle <- paste(paste(Types[1], Types[2], sep="+"), 'comparison')
  } else {
    subtitle <- NULL
  }
  
  if (length(Conditions)==2) {
    title <- paste(Conditions[1], 'vs', Conditions[2])
  } else {
    title <- paste('Comparison of fraction origin')
  }

  # --------------------------------------------------------------------------
  # Handle edge case of zero p-values
  # --------------------------------------------------------------------------
  if (min(DiffPropResult$padj, na.rm = TRUE) == 0) {
    warning(paste("One or more p-values is 0.", "Converting to 10^-1 * current", 
                  "lowest non-zero p-value..."), call. = FALSE)
    # Replace zeros with small non-zero value
    DiffPropResult$padj[which(DiffPropResult$padj == 0)] <- 
      min(DiffPropResult$padj[which(DiffPropResult$padj != 0)], na.rm = TRUE) * 10^-1
  }
  
  # Set y-axis limit
  if (length(cutoff) > 0) {
    ymax <- cutoff
  } else {
    ymax <- max(-log10(DiffPropResult$padj), na.rm = TRUE) + 5
  }
  
  # --------------------------------------------------------------------------
  # Create volcano plot
  # --------------------------------------------------------------------------
  PlotVolcano <- function(DiffPropResult, title = title, subtitle = NULL) {

    # Define thresholds
    FCcutoff <- 0.1
    pCutoff <- 0.01

    # Prepare the data
    df <- DiffPropResult %>%
      mutate(
        neg_log_padj = -log10(.data$padj),
        significance = case_when(
          .data$padj < pCutoff & abs(.data$mean_diff) > FCcutoff ~ "Significant + Large shift",
          .data$padj < pCutoff ~ "Significant",
          abs(.data$mean_diff) > FCcutoff ~ "Large shift",
          TRUE ~ "NS"
        )
      )

    # Define color palette 
    color_map <- c(
      "NS" = "grey70",
      "Large shift" = "#3B9AB2",
      "Significant" = "#EBCC2A",
      "Significant + Large shift" = "#F21A00"
    )

    # Determine y-axis limit
    ymax <- max(df$neg_log_padj, na.rm = TRUE) * 1.05

    # Build the plot
    p <- ggplot(df, aes(x = .data$mean_diff, y = .data$neg_log_padj, color = .data$significance)) +
      geom_point(size = 2.5, alpha = 0.8) +
      geom_vline(xintercept = c(-FCcutoff, FCcutoff), linetype = "dashed", color = "grey40") +
      geom_hline(yintercept = -log10(pCutoff), linetype = "dashed", color = "grey40") +
      scale_color_manual(values = color_map, name = NULL) +
      labs(
        title = title,
        subtitle = subtitle,
        x = "Proportion shift",
        y = expression(-log[10](adj.P))
      ) +
      theme_minimal(base_size = 15) +
      theme(
        plot.title = element_text(size = 20, face = "bold"),
        plot.subtitle = element_text(size = 16),
        axis.title = element_text(size = 16),
        legend.position = "right",
        legend.text = element_text(size = 14)
      ) +
      xlim(
        min(df$mean_diff, na.rm = TRUE) - 0.1,
        max(df$mean_diff, na.rm = TRUE) + 0.1
      ) +
      ylim(0, ymax)

    return(p)
  }
  PlotTrans <- PlotVolcano(DiffPropResult, title=title)  
  return(PlotTrans)    
}

#' get_corrected_counts: Reconstruct Count Matrix from Proportion Estimates
#'
#' @description
#' Returns the corrected count matrix embedded in a \code{FracFixR()} result
#' object. This matrix is computed internally by multiplying each transcript's
#' proportion estimate by the predicted total abundance for that replicate,
#' providing counts that are corrected for compositional bias while remaining
#' on the original count scale.
#'
#' If you need to re-scale using the raw (observed) Total counts instead of the
#' NNLS-predicted totals, multiply \code{fracfixr_results$Propestimates} by the
#' corresponding column of \code{fracfixr_results$OriginalData} manually.
#'
#' @param fracfixr_results Output list from \code{\link{FracFixR}}, which must
#'   contain the element \code{NewData}.
#'
#' @return A numeric matrix with the same dimensions as
#'   \code{fracfixr_results$Propestimates}, where non-Total columns contain
#'   corrected counts (rounded integers) and the Total column contains the
#'   NNLS-predicted total abundance.
#'
#' @examples
#' data(example_counts)
#' data(example_annotation)
#'
#' results <- FracFixR(example_counts, example_annotation, parallel = FALSE)
#' corrected <- get_corrected_counts(results)
#' head(corrected)
#'
#' @export
get_corrected_counts <- function(fracfixr_results) {
  if (is.null(fracfixr_results$NewData)) {
    stop("'fracfixr_results' does not contain a 'NewData' element. ",
         "Please re-run FracFixR() with version >= 1.1.0.")
  }
  return(fracfixr_results$NewData)
}

# Test file for FracFixR package
# Run tests with: devtools::test()

context("FracFixR main functions")

# Helper function to create test data
create_test_data <- function(n_genes = 100, n_samples = 12, seed = 123) {
  set.seed(seed)
  
  # Create count matrix
  counts <- matrix(
    rnbinom(n_genes * n_samples, mu = 100, size = 10),
    nrow = n_genes,
    dimnames = list(
      paste0("Gene", 1:n_genes),
      paste0("Sample", 1:n_samples)
    )
  )
  
  # Create annotation
  annotation <- data.frame(
    Sample = paste0("Sample", 1:12),
    Condition = rep(c("Control", "Treatment"), each = 6),
    Type = rep(c("Total", "Light", "Heavy"), 4),
    Replicate = c(rep("Rep1", 3), rep("Rep2", 3), rep("Rep1", 3), rep("Rep2", 3)),
    stringsAsFactors = FALSE
  )
  
  list(counts = counts, annotation = annotation)
}

# Test FracFixR main function
test_that("FracFixR handles basic input correctly", {
  # Create test data
  test_data <- create_test_data()
  
  # Run FracFixR
  expect_no_error(
    result <- FracFixR(test_data$counts, test_data$annotation)
  )
  
  # Check result structure
  expect_is(result, "list")
  expect_equal(
    names(result), 
    c("OriginalData", "Annotation", "Propestimates", "NewData", 
      "Coefficients", "Fractions", "plots")
  )
  
  # Check data dimensions
  expect_equal(nrow(result$OriginalData), nrow(test_data$counts))
  expect_equal(ncol(result$NewData), ncol(test_data$counts))
  
  # Check that fractions sum to <= 1
  frac_sums <- rowSums(result$Fractions[, !names(result$Fractions) %in% "Replicate"])
  expect_true(all(frac_sums <= 1.01)) # Allow small numerical error
})

test_that("FracFixR requires Total samples", {
  test_data <- create_test_data()
  
  # Remove Total samples
  bad_annotation <- test_data$annotation
  bad_annotation$Type[bad_annotation$Type == "Total"] <- "Other"
  
  expect_error(
    FracFixR(test_data$counts, bad_annotation),
    "at least one sample with Type == 'Total'"
  )
})

test_that("FracFixR validates input structure", {
  test_data <- create_test_data()
  
  # Test with data.frame instead of matrix
  expect_error(
    FracFixR(as.data.frame(test_data$counts), test_data$annotation),
    "must be a numeric matrix"
  )
  
  # Test with missing column names
  bad_counts <- test_data$counts
  colnames(bad_counts) <- NULL
  expect_error(
    FracFixR(bad_counts, test_data$annotation),
    "must have column names"
  )
  
  # Test with missing required annotation columns
  bad_annotation <- test_data$annotation[, -which(names(test_data$annotation) == "Type")]
  expect_error(
    FracFixR(test_data$counts, bad_annotation),
    "must contain required columns"
  )
})

test_that("FracFixR handles edge cases", {
  # Test with minimal data (2 samples per condition)
  test_data <- create_test_data(n_genes = 50, n_samples = 6)
  test_data$annotation <- data.frame(
    Sample = paste0("Sample", 1:6),
    Condition = rep(c("Control", "Treatment"), each = 3),
    Type = rep(c("Total", "Light", "Heavy"), 2),
    Replicate = rep("Rep1", 6),
    stringsAsFactors = FALSE
  )
  
  expect_warning(
    result <- FracFixR(test_data$counts, test_data$annotation),
    "fewer than 2 replicates"
  )
})

# Test ProcessReplicate function
test_that("ProcessReplicate works correctly", {
  # Create simple test data
  set.seed(123)
  test_mat <- data.frame(
    Total = c(100, 200, 150, 180, 120),
    Fraction1 = c(30, 60, 45, 54, 36),
    Fraction2 = c(50, 100, 75, 90, 60)
  )
  rownames(test_mat) <- paste0("Gene", 1:5)
  
  transcript_list <- paste0("Gene", 1:5)
  
  # Run ProcessReplicate
  result <- ProcessReplicate(test_mat, transcript_list)
  
  # Check result structure
  expect_is(result, "list")
  expect_equal(
    names(result),
    c("Propestimates", "NewData", "Coefficients", "Fractions", "plot")
  )
  
  # Check dimensions
  expect_equal(dim(result$Propestimates), dim(test_mat))
  expect_equal(dim(result$NewData), dim(test_mat))
})

test_that("ProcessReplicate requires Total column", {
  # Test data without Total column
  bad_mat <- data.frame(
    Fraction1 = c(30, 60, 45),
    Fraction2 = c(50, 100, 75)
  )
  
  expect_error(
    ProcessReplicate(bad_mat, rownames(bad_mat)),
    "must include a column named 'Total'"
  )
})

# Test DiffPropTest function
test_that("DiffPropTest performs differential testing", {
  # Create and process test data
  test_data <- create_test_data(n_genes = 50)
  fracfixr_result <- FracFixR(test_data$counts, test_data$annotation)
  
  # Test GLM method
  diff_result <- DiffPropTest(
    fracfixr_result,
    Conditions = c("Control", "Treatment"),
    Types = "Heavy",
    Test = "GLM"
  )
  
  # Check result structure
  expect_is(diff_result, "data.frame")
  expect_equal(
    names(diff_result),
    c("transcript", "mean_success_cond1", "mean_success_cond2", 
      "mean_diff", "log2FC", "pval", "padj")
  )
  
  # Check that p-values are in valid range
  valid_pvals <- !is.na(diff_result$pval)
  expect_true(all(diff_result$pval[valid_pvals] >= 0))
  expect_true(all(diff_result$pval[valid_pvals] <= 1))
  
  # Check that adjusted p-values are >= raw p-values
  valid_both <- !is.na(diff_result$pval) & !is.na(diff_result$padj)
  expect_true(all(diff_result$padj[valid_both] >= diff_result$pval[valid_both]))
})

test_that("DiffPropTest handles multiple fraction types", {
  test_data <- create_test_data(n_genes = 50)
  fracfixr_result <- FracFixR(test_data$counts, test_data$annotation)
  
  # Test with combined fractions
  diff_result <- DiffPropTest(
    fracfixr_result,
    Conditions = c("Control", "Treatment"),
    Types = c("Light", "Heavy"),
    Test = "GLM"
  )
  
  expect_is(diff_result, "data.frame")
  expect_equal(nrow(diff_result), nrow(fracfixr_result$OriginalData))
})

test_that("DiffPropTest validates inputs", {
  test_data <- create_test_data()
  fracfixr_result <- FracFixR(test_data$counts, test_data$annotation)
  
  # Test with invalid condition
  expect_error(
    DiffPropTest(fracfixr_result, 
                Conditions = c("Control", "Invalid"),
                Types = "Heavy",
                Test = "GLM"),
    "not found in NormObject\\$Annotation"
  )
  
  # Test with invalid type
  expect_error(
    DiffPropTest(fracfixr_result,
                Conditions = c("Control", "Treatment"),
                Types = "Invalid",
                Test = "GLM"),
    "not found in NormObject\\$Annotation"
  )
})

# Test visualization functions
test_that("PlotFractions creates valid plot", {
  test_data <- create_test_data()
  fracfixr_result <- FracFixR(test_data$counts, test_data$annotation)
  
  plot_obj <- PlotFractions(fracfixr_result)
  
  expect_is(plot_obj, "ggplot")
  expect_is(plot_obj, "gg")
})

test_that("PlotComparison creates valid volcano plot", {
  test_data <- create_test_data(n_genes = 50)
  fracfixr_result <- FracFixR(test_data$counts, test_data$annotation)
  
  diff_result <- DiffPropTest(
    fracfixr_result,
    Conditions = c("Control", "Treatment"),
    Types = "Heavy",
    Test = "GLM"
  )
  
  plot_obj <- PlotComparison(
    diff_result,
    Conditions = c("Control", "Treatment"),
    Types = "Heavy"
  )
  
  expect_is(plot_obj, "ggplot")
})

# Test reproducibility
test_that("FracFixR is reproducible with same seed", {
  test_data1 <- create_test_data(seed = 42)
  test_data2 <- create_test_data(seed = 42)
  
  result1 <- FracFixR(test_data1$counts, test_data1$annotation)
  result2 <- FracFixR(test_data2$counts, test_data2$annotation)
  
  # Check that coefficients are identical
  expect_equal(result1$Coefficients, result2$Coefficients)
  expect_equal(result1$Fractions, result2$Fractions)
})

# Test performance with larger datasets
test_that("FracFixR handles larger datasets", {
  skip_on_cran() # Skip on CRAN to save time
  
  # Create larger dataset (scale genes, keep samples at 12 to match annotation)
  large_data <- create_test_data(n_genes = 1000, n_samples = 12)
  
  # Time the execution
  start_time <- Sys.time()
  result <- FracFixR(large_data$counts, large_data$annotation)
  end_time <- Sys.time()
  
  # Check it completes in reasonable time (< 60 seconds)
  time_diff <- as.numeric(difftime(end_time, start_time, units = "secs"))
  expect_lt(time_diff, 60)
  
  # Check result is valid
  expect_is(result, "list")
  expect_equal(nrow(result$OriginalData), 1000)
})

# FracFixR Quick Reference Guide

## Installation
```r
# From CRAN
install.packages("FracFixR")

# From GitHub
devtools::install_github("Arnaroo/FracFixR")
```

## Basic Workflow

### 1. Load Package and Data
```r
library(FracFixR)

# Your data
counts <- as.matrix(read.csv("counts.csv", row.names = 1))
annotation <- read.csv("annotation.csv")
```

### 2. Run FracFixR
```r
results <- FracFixR(MatrixCounts = counts, 
                    Annotation = annotation)
```

### 3. Visualize Fractions
```r
PlotFractions(results)
```

### 4. Differential Testing
```r
diff_results <- DiffPropTest(results,
                            Conditions = c("Control", "Treatment"),
                            Types = "Heavy_Polysome",
                            Test = "GLM")
```

### 5. Volcano Plot
```r
PlotComparison(diff_results,
               Conditions = c("Control", "Treatment"),
               Types = "Heavy_Polysome")
```

## Key Functions

| Function | Purpose | Key Parameters |
|----------|---------|----------------|
| `FracFixR()` | Main analysis | `MatrixCounts`, `Annotation` |
| `DiffPropTest()` | Differential testing | `NormObject`, `Conditions`, `Types`, `Test` |
| `PlotFractions()` | Visualize proportions | `FracFixed` |
| `PlotComparison()` | Volcano plot | `DiffPropResult`, `Conditions`, `Types` |

## Annotation Requirements

Required columns:
- **Sample**: Must match column names in count matrix
- **Condition**: Experimental conditions
- **Type**: Fraction types (must include "Total")
- **Replicate**: Replicate identifiers

Example:
```
Sample    Condition  Type    Replicate
Sample1   Control    Total   Rep1
Sample2   Control    Light   Rep1
Sample3   Control    Heavy   Rep1
```

## Statistical Tests

- **GLM** (default): Most powerful, binomial GLM
- **Logit**: Faster, logit transformation
- **Wald**: Beta-binomial for overdispersed data

## Common Analyses

### Single Fraction
```r
diff_heavy <- DiffPropTest(results,
                          Conditions = c("A", "B"),
                          Types = "Heavy")
```

### Combined Fractions
```r
diff_combined <- DiffPropTest(results,
                             Conditions = c("A", "B"),
                             Types = c("Light", "Heavy"))
```

### Filter Results
```r
# Significant genes
sig_genes <- diff_results[diff_results$padj < 0.01, ]

# Top changed genes
top_genes <- diff_results[order(abs(diff_results$mean_diff), 
                                decreasing = TRUE), ][1:50, ]
```

## Output Components

`FracFixR()` returns:
- `$OriginalData`: Filtered input counts
- `$Annotation`: Sample annotation
- `$Propestimates`: Proportion estimates
- `$NewData`: Corrected counts
- `$Coefficients`: Regression coefficients
- `$Fractions`: Fraction proportions
- `$plots`: Diagnostic plots

`DiffPropTest()` returns:
- `transcript`: Gene/transcript ID
- `mean_success_cond1/2`: Mean proportions
- `mean_diff`: Difference in proportions
- `log2FC`: Log2 fold change
- `pval`: Raw p-value
- `padj`: FDR-adjusted p-value

## Tips

1. **Check Total samples**: Ensure each condition-replicate has a "Total"
2. **Minimum replicates**: Use ≥2 replicates per condition
3. **Parallel processing**: Automatic, uses available cores
4. **Memory**: For >50k genes, pre-filter low counts
5. **Interpretation**: Positive mean_diff = higher in condition 2

## Example Datasets

```r
# Polysome profiling
data(example_counts)
data(example_annotation)

# Alternative annotations
data(polysome_annotation)    # Monosome/Polysome
data(subcellular_annotation)  # Nuclear/Cytoplasmic
```

## Troubleshooting

See full troubleshooting guide in package documentation or:
```r
vignette("FracFixR-intro")
help(FracFixR)
```

## Citation

```r
citation("FracFixR")
```

Cleynen et al. (2024) FracFixR: A compositional statistical framework for absolute proportion estimation between fractions in RNA sequencing data. *Bioinformatics*.

---
title: "Introduction to FracFixR"
author: "Alice Cleynen, Agin Ravindran, Nikolay Shirokikh"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Introduction to FracFixR}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 7,
  fig.height = 5
)
```

## Introduction

FracFixR is a compositional statistical framework for analyzing RNA-seq data from fractionation experiments. It addresses the fundamental challenge where library preparation and sequencing depth obscure the original proportions of RNA fractions.

This vignette demonstrates:

1. Basic usage with polysome profiling data
2. Differential proportion testing
3. Visualization of results
4. Advanced applications

## Installation

```{r installation, eval=FALSE}
# From CRAN
install.packages("FracFixR")

# From GitHub (development version)
devtools::install_github("Arnaroo/FracFixR")
```

## Quick Start Example

Let's simulate a simple polysome profiling experiment:

```{r load_package}
library(FracFixR)

# Set seed for reproducibility
set.seed(123)
```

### Creating Example Data

```{r create_data}
# Simulate count data for 500 genes across 12 samples
n_genes <- 100
n_samples <- 12

# Generate count matrix with varying expression levels
total_counts <- matrix(
  rnbinom(n_genes * 4, mu = 100, size = 10),
  nrow = n_genes,
  dimnames = list(
    paste0("Gene", 1:n_genes),
    paste0("Sample", 1:4)
  )
)
prob=c(1/4,1/4,1/2)

# distribute counts evenly accross different fractions in Control
multinom_samples <- apply(total_counts, c(1, 2), function(x) rmultinom(1, size = x, prob = prob))
reshaped <- aperm(multinom_samples, c(3, 2, 1))  # now (n, 4, 3)
reshaped_matrix1 <- matrix(reshaped, nrow = n_genes, ncol = 12)
colnames(reshaped_matrix1) <- paste0("V", rep(1:4, each = 3), "_p", 1:3)

counts<-cbind(total_counts[,1:2],reshaped_matrix1[,c(2:3,5:6)],total_counts[,3:4],reshaped_matrix1[,c(8:9,11:12)])

# Create annotation data frame
annotation <- data.frame(
  Sample = colnames(counts),
  Condition = rep(c("Control", "Treatment"), each = 6),
  Type = rep(c("Total", "Total", "Light_Polysome", "Heavy_Polysome","Light_Polysome", "Heavy_Polysome"), 2),
  Replicate = c("Rep1","Rep2", rep("Rep1", 2), rep("Rep2", 2), "Rep1","Rep2", rep("Rep1", 2), rep("Rep2", 2))
)

print(head(annotation))
```

### Running FracFixR

```{r run_fracfixr}
# Run the main analysis
results <- FracFixR(MatrixCounts = counts, Annotation = annotation)

# View the structure of results
names(results)
```

### Understanding the Output

The FracFixR output contains several components:

```{r explore_output}
# 1. Fraction proportions for each replicate
print(results$Fractions)

# 2. Regression coefficients
print(results$Coefficients)

# 3. Estimated Proportions (first 5 genes, first 6 samples)
print(results$Propestimates[1:5, 1:6])
```

## Visualizing Fraction Proportions

```{r plot_fractions, fig.cap="Fraction proportions across replicates"}
# Create fraction plot
frac_plot <- PlotFractions(results)
print(frac_plot)
```

The plot shows:
- The proportion of RNA in each fraction
- The "Lost" fraction (grey) representing unrecoverable material
- Consistency across replicates

## Differential Proportion Testing

Now let's identify genes with differential polysome association between conditions:

```{r diff_test}
# Test for differential proportion in heavy polysomes
diff_heavy <- DiffPropTest(
  NormObject = results,
  Conditions = c("Control", "Treatment"),
  Types = "Heavy_Polysome",
  Test = "Logit"
)

# View top differentially associated genes
top_genes <- diff_heavy[order(diff_heavy$padj), ]
print(head(top_genes, 10))
```

### Interpreting Results

- **mean_diff**: Difference in proportion between conditions
- **log2FC**: Log2 fold change of proportions
- **padj**: FDR-adjusted p-value

Positive mean_diff indicates higher proportion in Treatment.

## Creating a Volcano Plot

```{r volcano_plot, fig.cap="Volcano plot of differential polysome association"}
volcano <- PlotComparison(
  diff_heavy,
  Conditions = c("Control", "Treatment"),
  Types = "Heavy_Polysome",
  cutoff = 20
)
print(volcano)
```

### Data Requirements

For real experiments, ensure your data meets these requirements:

1. **Count Matrix**: Raw counts (not normalized)
2. **Annotation**: Must include:
   - Sample names matching count matrix columns
   - At least one "Total" sample per condition-replicate
   - Consistent fraction names across replicates


## Session Info

```{r session_info}
sessionInfo()
```

## References

Cleynen A, Ravindran A, Shirokikh N (2025). FracFixR: A compositional statistical framework for absolute proportion estimation between fractions in RNA sequencing data. 

For more examples and advanced usage, see the [FracFixR GitHub repository](https://github.com/Arnaroo/FracFixR).

# FracFixR Troubleshooting Guide

## Table of Contents
1. [Installation Issues](#installation-issues)
2. [Data Input Errors](#data-input-errors)
3. [Runtime Errors](#runtime-errors)
4. [Statistical Testing Issues](#statistical-testing-issues)
5. [Memory and Performance](#memory-and-performance)
6. [Interpretation Questions](#interpretation-questions)

## Installation Issues

### Problem: Package won't install from CRAN
```
Error: package 'FracFixR' is not available
```

**Solution:**
```r
# Check your R version
R.version.string  # Should be >= 4.0.0

# Try different CRAN mirror
chooseCRANmirror()
install.packages("FracFixR")

# Or install from GitHub
devtools::install_github("Arnaroo/FracFixR")
```

### Problem: Dependencies fail to install
```
Error: dependency 'EnhancedVolcano' is not available
```

**Solution:**
```r
# EnhancedVolcano is from Bioconductor
if (!require("BiocManager", quietly = TRUE))
    install.packages("BiocManager")
BiocManager::install("EnhancedVolcano")

# Then retry FracFixR installation
install.packages("FracFixR")
```

## Data Input Errors

### Problem: "All MatrixCounts columns must be in Annotation$Sample"

**Diagnosis:**
```r
# Check for mismatches
setdiff(colnames(counts), annotation$Sample)  # Shows columns not in annotation
setdiff(annotation$Sample, colnames(counts))  # Shows annotations without data
```

**Solutions:**
```r
# Fix whitespace issues
colnames(counts) <- trimws(colnames(counts))
annotation$Sample <- trimws(annotation$Sample)

# Fix case sensitivity
colnames(counts) <- gsub("sample", "Sample", colnames(counts))

# Check exact matches
all(colnames(counts) %in% annotation$Sample)  # Should be TRUE
```

### Problem: "Annotation must include at least one sample with Type == 'Total'"

**Solution:**
```r
# Check Type values
unique(annotation$Type)

# Common fixes:
# 1. Case sensitivity
annotation$Type <- gsub("total", "Total", annotation$Type)

# 2. Whitespace
annotation$Type <- trimws(annotation$Type)

# 3. Typos
annotation$Type[annotation$Type == "Totla"] <- "Total"

# Verify
any(annotation$Type == "Total")  # Should be TRUE
```

### Problem: "MatrixCounts must be a numeric matrix"

**Solution:**
```r
# Convert data.frame to matrix
counts <- as.matrix(counts)

# Ensure numeric
counts <- apply(counts, 2, as.numeric)

# Check for non-numeric values
which(is.na(counts), arr.ind = TRUE)  # Shows problematic cells

# Remove non-numeric rows/columns if needed
numeric_cols <- sapply(counts, is.numeric)
counts <- counts[, numeric_cols]
```

## Runtime Errors

### Problem: "No transcripts selected for regression in condition X"

**Diagnosis:**
```r
# Check transcript abundance distribution
total_samples <- annotation$Type == "Total" & annotation$Condition == "X"
total_counts <- rowSums(counts[, total_samples, drop = FALSE])
hist(log10(total_counts + 1), breaks = 50)
quantile(total_counts, c(0.7, 0.96))  # Default selection range
```

**Solutions:**
```r
# 1. Check if you have enough expressed genes
sum(total_counts > 0)  # Should be > 10

# 2. Check for sample swaps
# Ensure Total samples have higher counts than fractions

# 3. If legitimate low expression, contact maintainers for guidance
```

### Problem: "Each replicate must have at least two types"

**Solution:**
```r
# Check your annotation structure
table(annotation$Replicate, annotation$Type)

# Each replicate should have Total + at least one fraction
# Fix by ensuring complete experimental design
```

### Problem: Convergence warnings in GLM

**Solutions:**
```r
# 1. Try Wald test (more robust to extreme values)
diff_results <- DiffPropTest(results,
                            Conditions = c("A", "B"),
                            Types = "Fraction",
                            Test = "Wald")

# 2. Filter genes with very low counts
min_count_threshold <- 10
keep <- rowSums(counts) >= min_count_threshold
filtered_counts <- counts[keep, ]

# 3. Check for outlier samples
boxplot(log10(colSums(counts) + 1), las = 2)
```

## Statistical Testing Issues

### Problem: All p-values are NA

**Diagnosis:**
```r
# Check if you have replicates
table(annotation$Condition, annotation$Replicate)

# Check for zero counts in tested fractions
fraction_samples <- annotation$Type == "YourFraction"
sum(rowSums(counts[, fraction_samples]) > 0)
```

**Solution:**
- Ensure at least 2 replicates per condition
- Check that the tested fraction has non-zero counts
- Verify fraction names match exactly

### Problem: No significant results

**Checks:**
```r
# 1. Verify biological variability exists
# Plot PCA of your fractions
pca_data <- prcomp(t(log10(counts + 1)))
plot(pca_data$x[,1], pca_data$x[,2])

# 2. Check proportion distributions
hist(diff_results$mean_diff, breaks = 50)

# 3. Try less stringent threshold
sum(diff_results$pval < 0.05, na.rm = TRUE)  # Before multiple testing
```

### Problem: Different results with different tests

This is expected! The tests have different assumptions:
- **GLM**: Assumes binomial distribution, most powerful
- **Logit**: Uses transformation, faster but less powerful
- **Wald**: Accounts for overdispersion, more conservative

## Memory and Performance

### Problem: Out of memory errors

**Solutions:**
```r
# 1. Reduce parallel workers
library(future)
plan(multisession, workers = 2)  # Use only 2 cores

# 2. Pre-filter genes
keep <- rowSums(counts) >= 10  # Minimum total count
filtered_counts <- counts[keep, ]

# 3. Process in batches (contact maintainers for scripts)
```

### Problem: Analysis takes too long

**Solutions:**
```r
# 1. Check parallel processing is working
future::availableCores()

# 2. Use Logit test for initial exploration
diff_quick <- DiffPropTest(results, 
                          Conditions = c("A", "B"),
                          Types = "Fraction",
                          Test = "Logit")  # Faster

# 3. Reduce gene number for testing
test_counts <- counts[1:1000, ]  # Subset for testing
```

## Interpretation Questions

### Q: What does the "Lost" fraction represent?

The lost fraction includes:
- RNA lost during fractionation procedure
- RNA in fractions not sequenced (e.g., free RNA in polysome profiling)
- Technical losses during library preparation
- Degraded or damaged RNA

High lost fraction (>50%) may indicate technical issues.

### Q: How do I interpret mean_diff?

- **Positive mean_diff**: Higher proportion in condition 2
- **Negative mean_diff**: Higher proportion in condition 1
- **Magnitude**: Absolute change in proportion (0.1 = 10% change)

Example:
```
mean_diff = 0.15, padj < 0.01
→ Gene has 15% higher proportion in condition 2 (significant)
```

### Q: Can I use normalized counts as input?

**No!** FracFixR requires raw counts because:
- It performs its own compositional normalization
- Standard normalizations assume independence between samples
- Fractions are compositionally related (parts of a whole)

### Q: How many replicates do I need?

- **Minimum**: 2 per condition (will get warning)
- **Recommended**: 3+ per condition
- **For subtle changes**: 4-6 per condition

Power depends on:
- Effect size (proportion changes)
- Technical variability
- Number of genes tested

### Q: Can I compare more than 2 conditions?

Currently, DiffPropTest compares exactly 2 conditions at a time.

For multiple conditions:
```r
# Pairwise comparisons
diff_AvsB <- DiffPropTest(results, Conditions = c("A", "B"), ...)
diff_AvsC <- DiffPropTest(results, Conditions = c("A", "C"), ...)
diff_BvsC <- DiffPropTest(results, Conditions = c("B", "C"), ...)
```

## Getting Help

1. **Check documentation**:
   ```r
   ?FracFixR
   vignette("FracFixR-intro")
   ```

2. **Reproducible example**:
   ```r
   # Create minimal example
   set.seed(123)
   mini_counts <- matrix(rpois(100, 50), nrow = 10)
   # ... show the error
   ```

3. **Report issues**:
   - GitHub: https://github.com/Arnaroo/FracFixR/issues
   - Include: sessionInfo(), error message, minimal example

4. **Contact maintainers**:
   - General questions: fracfixr@gmail.com
   - Bug reports: Use GitHub issues

## Common Warnings (Usually Safe)

1. **"Some conditions have fewer than 2 replicates"**
   - Analysis will run but with limited statistical power

2. **"Only X transcripts selected for condition Y"**
   - If X > 10, analysis should be reliable
   - Check your data if X < 10

3. **"Converting 0 p-values"**
   - Very significant results, p-values below machine precision
   - Converted to small non-zero values for plotting

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{example_counts}
\alias{example_counts}
\title{Example RNA-seq count matrix}
\format{
A numeric matrix with 100 rows (genes) and 12 columns (samples):
\describe{
  \item{rows}{Gene identifiers (Gene1 to Gene100)}
  \item{columns}{Sample identifiers (Sample1 to Sample12)}
}
}
\source{
Simulated data generated for package examples
}
\usage{
example_counts
}
\description{
A matrix containing simulated RNA-seq counts for 100 genes across 12 samples.
The data simulates a polysome profiling experiment with two conditions
(Control and Treatment) and three fractions (Total, Light_Polysome, Heavy_Polysome).
}
\examples{
data(example_counts)
dim(example_counts)
head(example_counts[, 1:6])
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fracfixr.r
\name{get_corrected_counts}
\alias{get_corrected_counts}
\title{get_corrected_counts: Retrieve the Corrected Count Matrix}
\usage{
get_corrected_counts(fracfixr_results)
}
\arguments{
\item{fracfixr_results}{Output list from \code{\link{FracFixR}}, which must
contain the element \code{NewData} (present in results from version >= 1.1.0).}
}
\value{
A numeric matrix with the same dimensions as
  \code{fracfixr_results$Propestimates}. Non-Total columns contain corrected
  counts (rounded integers, proportion estimate multiplied by the
  NNLS-predicted total abundance). The Total column contains the
  NNLS-predicted total abundance itself.
}
\description{
Returns the corrected count matrix embedded in a \code{FracFixR()} result
object. This matrix is computed internally by multiplying each transcript's
proportion estimate by the predicted total abundance for that replicate,
providing counts that are corrected for compositional bias while remaining
on the original count scale.

If you need to re-scale using the raw (observed) Total counts instead of the
NNLS-predicted totals, multiply \code{fracfixr_results$Propestimates} by the
corresponding column of \code{fracfixr_results$OriginalData} manually.
}
\examples{
data(example_counts)
data(example_annotation)

results <- FracFixR(example_counts, example_annotation, parallel = FALSE)
corrected <- get_corrected_counts(results)
head(corrected)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fracfixr.r
\name{extract_condition_matrix}
\alias{extract_condition_matrix}
\title{extract_condition_matrix: Extract and Prepare Data for Statistical Testing}
\usage{
extract_condition_matrix(
  originalcounts,
  proportions,
  annotation,
  conditions,
  types
)
}
\arguments{
\item{originalcounts}{Original count matrix}

\item{proportions}{Proportion estimates from FracFixR}

\item{annotation}{Sample annotation data frame}

\item{conditions}{Vector of conditions to extract}

\item{types}{Vector of fraction types to analyze}
}
\value{
List containing:
  \itemize{
    \item counts: Total counts from whole cell samples
    \item successes: Proportion data for specified fractions
    \item annotation: Filtered and processed annotation
  }
}
\description{
Extracts count and proportion data for specified conditions and fraction types.
Handles both single fraction and combined fraction analyses.
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fracfixr.r
\name{logit_diff_test}
\alias{logit_diff_test}
\title{logit_diff_test: Logit-based Differential Test}
\usage{
logit_diff_test(counts, successes, annotation)
}
\arguments{
\item{counts}{Total count matrix}

\item{successes}{Proportion matrix}

\item{annotation}{Sample metadata}
}
\value{
Data frame with test results for all transcripts
}
\description{
Alternative to GLM using logit transformation. Faster but potentially
less powerful than the full GLM approach.
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fracfixr.r
\name{run_glm}
\alias{run_glm}
\title{run_glm: Binomial GLM for Single Transcript}
\usage{
run_glm(transcript, counts, successes, sample_info)
}
\arguments{
\item{transcript}{Transcript identifier}

\item{counts}{Total count matrix}

\item{successes}{Proportion matrix}

\item{sample_info}{Sample metadata with Condition factor}
}
\value{
Data frame with test results for this transcript
}
\description{
Fits a binomial generalized linear model to test for differential
proportions between conditions for a single transcript.
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fracfixr.r
\name{FracFixR}
\alias{FracFixR}
\title{FracFixR: Main Function for Fraction Correction}
\usage{
FracFixR(MatrixCounts, Annotation, st1 = 0.6, st2 = 0.999, parallel = TRUE)
}
\arguments{
\item{MatrixCounts}{A numeric matrix of raw transcript/gene counts with:
\itemize{
  \item Rows: transcripts/genes (must have rownames)
  \item Columns: samples (must have colnames matching Annotation$Sample)
}}

\item{Annotation}{A data.frame with required columns:
\itemize{
  \item Sample: sample identifiers matching column names in MatrixCounts
  \item Condition: experimental condition (e.g., "Control", "Treatment")
  \item Type: fraction type (must include at least one "Total")
  \item Replicate: replicate identifier
}}

\item{parallel}{A boolean indicating whether to use parallel processing of
the transcripts (default=TRUE).}

\item{st1}{Lower quantile threshold (between 0 and 1) for selecting
informative transcripts for the NNLS regression fit (default = 0.6).
Transcripts below this quantile of Total abundance are considered too noisy
for reliable regression.}

\item{st2}{Upper quantile threshold (between 0 and 1) for selecting
informative transcripts for the NNLS regression fit (default = 0.999).
Transcripts above this quantile are potential outliers and are excluded
from the regression.}
}
\value{
A list containing:
  \itemize{
    \item OriginalData: filtered input count matrix
    \item Annotation: input annotation data
    \item Propestimates: matrix of proportion estimates (values between 0 and 1)
    \item NewData: corrected count matrix (proportions multiplied by predicted total, rounded)
    \item Coefficients: data.frame of regression coefficients
    \item Fractions: data.frame of estimated fraction proportions
    \item plots: list of diagnostic plots
  }
}
\description{
This is the core function that implements the FracFixR framework. It takes
raw count data from total and fractionated samples and reconstructs the
original fraction proportions through compositional modeling.
}
\details{
The function works by:
\enumerate{
  \item Filtering transcripts based on presence in Total samples
  \item For each condition and replicate, fitting NNLS regression
  \item Estimating global fraction weights and individual transcript proportions
  \item Calculating the "lost" unrecoverable fraction
}
}
\examples{
# Load example data
data(example_counts)
data(example_annotation)

# Run FracFixR
results <- FracFixR(example_counts, example_annotation, parallel=FALSE)

# View fraction proportions
print(results$Fractions)

}
\references{
Cleynen et al. FracFixR: A compositional statistical framework for
absolute proportion estimation between fractions in RNA sequencing data.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fracfixr.r
\name{PlotFractions}
\alias{PlotFractions}
\title{PlotFractions: Visualize Fraction Proportions}
\usage{
PlotFractions(FracFixed)
}
\arguments{
\item{FracFixed}{Output from FracFixR() function}
}
\value{
ggplot2 object showing fraction proportions
}
\description{
Creates a stacked bar plot showing the distribution of RNA across fractions
for each replicate, including the "lost" fraction.
}
\examples{
data(example_counts)
data(example_annotation)

# Run FracFixR
results <- FracFixR(example_counts, example_annotation, parallel=FALSE)
# Create fraction plot
frac_plot <- PlotFractions(results)
# Save plot with ggsave("fractions.pdf", frac_plot, width = 10, height = 8)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fracfixr.r
\name{ProcessReplicate}
\alias{ProcessReplicate}
\title{ProcessReplicate: Core NNLS Regression for Individual Replicates}
\usage{
ProcessReplicate(RepMat, transcriptlist)
}
\arguments{
\item{RepMat}{Data frame with transcripts as rows, samples as columns.
Must include a "Total" column representing the whole cell lysate}

\item{transcriptlist}{Character vector of transcript IDs to use for regression.
These should be informative transcripts in the appropriate abundance range}
}
\value{
List containing:
  \itemize{
    \item Propestimates: Proportion estimates for each transcript (values 0-1 for fraction columns)
    \item NewData: Corrected count matrix (proportions multiplied by predicted total, rounded)
    \item Coefficients: NNLS regression coefficients (fraction weights)
    \item Fractions: Normalized fraction proportions
    \item plot: Diagnostic plot of fitted vs residuals
  }
}
\description{
This function implements the mathematical core of FracFixR: fitting a
non-negative least squares (NNLS) regression to estimate fraction weights
and correct individual transcript abundances.
}
\details{
Mathematical basis:
\deqn{Total = \alpha_0 + \alpha_1 \times Fraction1 + \alpha_2 \times Fraction2 + ... + \epsilon}
Where \eqn{\alpha_0} represents the "lost" fraction and other \eqn{\alpha_i} are fraction weights
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fracfixr.r
\name{beta_binomial_wald}
\alias{beta_binomial_wald}
\title{beta_binomial_wald: Beta-Binomial Wald Test}
\usage{
beta_binomial_wald(counts, successes, annotation)
}
\arguments{
\item{counts}{Total count matrix}

\item{successes}{Success count matrix (not proportions)}

\item{annotation}{Sample metadata}
}
\value{
Data frame with test results for all transcripts
}
\description{
Implements Wald test using beta-binomial distribution to account for
overdispersion in count data. Useful when variance exceeds that expected
under binomial distribution.
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fracfixr.r
\name{DiffPropTest}
\alias{DiffPropTest}
\title{DiffPropTest: Statistical Testing for Differential Proportions}
\usage{
DiffPropTest(NormObject, Conditions, Types, Test = c("GLM", "Logit", "Wald"))
}
\arguments{
\item{NormObject}{Output from FracFixR() function}

\item{Conditions}{Character vector of exactly 2 conditions to compare}

\item{Types}{Character vector of fraction type(s) to analyze.
Can be single fraction or multiple (will be combined)}

\item{Test}{Statistical test to use: "GLM", "Logit", or "Wald"}
}
\value{
Data frame with columns:
  \itemize{
    \item transcript: transcript identifier
    \item mean_success_cond1/2: mean proportions in each condition
    \item mean_diff: difference in proportions
    \item log2FC: log2 fold change
    \item pval: p-value from statistical test
    \item padj: FDR-adjusted p-value
  }
}
\description{
Performs statistical testing to identify transcripts with significantly
different proportions between conditions in specified fraction(s).
Implements three test options: GLM (most powerful), Logit, and Wald.
}
\details{
\itemize{
  \item GLM: Uses binomial generalized linear model (most statistically powerful)
  \item Logit: Faster alternative using logit transformation
  \item Wald: Beta-binomial Wald test for overdispersed count data
}
}
\examples{
data(example_counts)
data(example_annotation)

# Run FracFixR
results <- FracFixR(example_counts, example_annotation, parallel=FALSE)
# Run differential testing
diff_results <- DiffPropTest(results,
                            Conditions = c("Control", "Treatment"),
                            Types = "Heavy_Polysome",
                            Test = "GLM")

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fracfixr.r
\docType{package}
\name{FracFixR-package}
\alias{FracFixR-package}
\title{FracFixR: Fraction Correction Framework for RNA-seq Data}
\description{
A compositional statistical framework for absolute proportion estimation 
between fractions in RNA sequencing data. FracFixR addresses the fundamental
challenge in fractionated RNA-seq experiments where library preparation and
sequencing depth obscure the original proportions of RNA fractions.
}
\author{
\strong{Maintainer}: Alice Cleynen \email{alice.cleynen@cnrs.fr} (\href{https://orcid.org/0000-0001-8083-0204}{ORCID})

Authors:
\itemize{
  \item Agin Ravindran
  \item Nikolay Shirokikh \email{nikolay.shirokikh@uwa.edu.au} (\href{https://orcid.org/0000-0001-8249-358X}{ORCID})
}

}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fracfixr.r
\name{PlotComparison}
\alias{PlotComparison}
\title{PlotComparison: Create Volcano Plot for Differential Results}
\usage{
PlotComparison(DiffPropResult, Conditions = NULL, Types = NULL, cutoff = NULL)
}
\arguments{
\item{DiffPropResult}{Output from DiffPropTest() function}

\item{Conditions}{Character vector of conditions being compared}

\item{Types}{Character vector of fraction types analyzed}

\item{cutoff}{Optional y-axis maximum for plot}
}
\value{
Volcano plot-type object
}
\description{
Generates avolcano plot showing transcripts with significant
differential proportions between conditions.
}
\examples{
data(example_counts)
data(example_annotation)

# Run FracFixR
results <- FracFixR(example_counts, example_annotation,parallel=FALSE)
# Run differential testing
diff_results <- DiffPropTest(results,
                            Conditions = c("Control", "Treatment"),
                            Types = "Heavy_Polysome",
                            Test = "GLM")
# Create volcano plot
volcano <- PlotComparison(diff_results, 
                         Conditions = c("Control", "Treatment"),
                         Types = "Heavy_Polysome")

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{polysome_annotation}
\alias{polysome_annotation}
\title{Polysome profiling annotation example}
\format{
A data frame with 12 rows and 4 columns:
\describe{
  \item{Sample}{Sample identifier}
  \item{Condition}{Experimental condition (Control or Stress)}
  \item{Type}{Fraction type (Total, Monosome, or Polysome)}
  \item{Replicate}{Replicate identifier (Rep1 or Rep2)}
}
}
\source{
Simulated data generated for package examples
}
\usage{
polysome_annotation
}
\description{
An alternative annotation data frame for polysome profiling experiments
with monosome and polysome fractions.
}
\examples{
data(polysome_annotation)
head(polysome_annotation)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{example_annotation}
\alias{example_annotation}
\title{Example annotation data frame}
\format{
A data frame with 12 rows and 4 columns:
\describe{
  \item{Sample}{Sample identifier matching column names in example_counts}
  \item{Condition}{Experimental condition (Control or Treatment)}
  \item{Type}{Fraction type (Total, Light_Polysome, or Heavy_Polysome)}
  \item{Replicate}{Replicate identifier (Rep1 or Rep2)}
}
}
\source{
Simulated data generated for package examples
}
\usage{
example_annotation
}
\description{
A data frame containing sample annotations for the example_counts matrix.
Describes the experimental design with conditions, fraction types, and replicates.
}
\examples{
data(example_annotation)
head(example_annotation)
table(example_annotation$Condition, example_annotation$Type)
}
\keyword{datasets}
